@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -101,7 +101,7 @@ QString BuiltinCommandLineOption::executeCommand(const QString &option_string, c
         if(args.isEmpty())
             return out;
         QStringList full_path_list, remote_pls_list;
-        foreach(QString s, args)
+        for(QString s : qAsConst(args))
         {
 #ifdef Q_OS_WIN
             s.replace("\\","/");
@@ -232,7 +232,7 @@ QHash <QString, QStringList> BuiltinCommandLineOption::splitArgs(const QStringLi
 {
     QHash <QString, QStringList> commands;
     QString lastCmd;
-    foreach(QString arg, args)
+    for(const QString &arg : qAsConst(args))
     {
         QString cmd = arg.trimmed();
         if(cmd.startsWith("-") || cmd.startsWith("--"))
