@@ -41,7 +41,7 @@
     <message>
         <location filename="../builtincommandlineoption.cpp" line="78"/>
         <source>Set playback volume (example: qmmp --volume 20)</source>
-        <translation>Setel volume pemainan (contohnya: qmmp --volume 20)</translation>
+        <translation>Setel volume pemutaran (contohnya: qmmp --volume 20)</translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="79"/>
@@ -92,88 +92,88 @@
 <context>
     <name>QMMPStarter</name>
     <message>
-        <location filename="../qmmpstarter.cpp" line="113"/>
+        <location filename="../qmmpstarter.cpp" line="108"/>
         <source>Unknown command</source>
         <translation>Perintah tak diketahui</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="413"/>
+        <location filename="../qmmpstarter.cpp" line="408"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>Penggunaan: qmmp [pilihan] [file]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="414"/>
+        <location filename="../qmmpstarter.cpp" line="409"/>
         <source>Options:</source>
         <translation>Pilihan:</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="420"/>
+        <location filename="../qmmpstarter.cpp" line="415"/>
         <source>Start qmmp with the specified user interface</source>
         <translation>Start qmmp dengan antarmuka pengguna yang ditentukan</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="421"/>
+        <location filename="../qmmpstarter.cpp" line="416"/>
         <source>List all available user interfaces</source>
         <translation>Daftar semua antarmuka pengguna yang tersedia</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="422"/>
+        <location filename="../qmmpstarter.cpp" line="417"/>
         <source>Don&apos;t start the application</source>
         <translation>Jangan mulaikan aplikasi</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="423"/>
+        <location filename="../qmmpstarter.cpp" line="418"/>
         <source>Display this text and exit</source>
         <translation>Tayangkan teks ini dan keluar</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="424"/>
+        <location filename="../qmmpstarter.cpp" line="419"/>
         <source>Print version number and exit</source>
         <translation>Cetak nomor versi dan keluar</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="426"/>
+        <location filename="../qmmpstarter.cpp" line="421"/>
         <source>Home page: %1</source>
         <translation>Beranda: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="427"/>
+        <location filename="../qmmpstarter.cpp" line="422"/>
         <source>Development page: %1</source>
         <translation>Halaman pengembang: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="428"/>
+        <location filename="../qmmpstarter.cpp" line="423"/>
         <source>Bug tracker: %1</source>
         <translation>Pelacak bug: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="135"/>
-        <location filename="../qmmpstarter.cpp" line="433"/>
+        <location filename="../qmmpstarter.cpp" line="130"/>
+        <location filename="../qmmpstarter.cpp" line="428"/>
         <source>Command Line Help</source>
         <translation>Bantuan Baris Perintah</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="446"/>
+        <location filename="../qmmpstarter.cpp" line="441"/>
         <source>QMMP version: %1</source>
         <translation>Versi QMMP: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="447"/>
+        <location filename="../qmmpstarter.cpp" line="442"/>
         <source>Compiled with Qt version: %1</source>
         <translation>Dikompilasi dengan versi Qt: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="448"/>
+        <location filename="../qmmpstarter.cpp" line="443"/>
         <source>Using Qt version: %1</source>
         <translation>Menggunakan versi Qt: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="451"/>
+        <location filename="../qmmpstarter.cpp" line="446"/>
         <source>Qmmp Version</source>
         <translation>Versi Qmmp</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="468"/>
+        <location filename="../qmmpstarter.cpp" line="463"/>
         <source>User Interfaces</source>
         <translation>Antarmuka Pengguna</translation>
     </message>
