@@ -92,88 +92,88 @@
 <context>
     <name>QMMPStarter</name>
     <message>
-        <location filename="../qmmpstarter.cpp" line="113"/>
+        <location filename="../qmmpstarter.cpp" line="108"/>
         <source>Unknown command</source>
         <translation>Onbekend commando</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="413"/>
+        <location filename="../qmmpstarter.cpp" line="408"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>Gebruik: qmmp [opties] [bestanden]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="414"/>
+        <location filename="../qmmpstarter.cpp" line="409"/>
         <source>Options:</source>
         <translation>Opties:</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="420"/>
+        <location filename="../qmmpstarter.cpp" line="415"/>
         <source>Start qmmp with the specified user interface</source>
         <translation>Qmmp starten met opgegeven uiterlijk</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="421"/>
+        <location filename="../qmmpstarter.cpp" line="416"/>
         <source>List all available user interfaces</source>
         <translation>Alle varianten van uiterlijk tonen</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="422"/>
+        <location filename="../qmmpstarter.cpp" line="417"/>
         <source>Don&apos;t start the application</source>
         <translation>Niet de applicatie starten</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="423"/>
+        <location filename="../qmmpstarter.cpp" line="418"/>
         <source>Display this text and exit</source>
         <translation>Toon deze tekst en sluit</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="424"/>
+        <location filename="../qmmpstarter.cpp" line="419"/>
         <source>Print version number and exit</source>
-        <translation>Print versienummer en sluit</translation>
+        <translation>Versienummer tonen en afsluiten</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="426"/>
+        <location filename="../qmmpstarter.cpp" line="421"/>
         <source>Home page: %1</source>
         <translation>Website: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="427"/>
+        <location filename="../qmmpstarter.cpp" line="422"/>
         <source>Development page: %1</source>
         <translation>Ontwikkelaarspagina: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="428"/>
+        <location filename="../qmmpstarter.cpp" line="423"/>
         <source>Bug tracker: %1</source>
         <translation>Bugtracker: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="135"/>
-        <location filename="../qmmpstarter.cpp" line="433"/>
+        <location filename="../qmmpstarter.cpp" line="130"/>
+        <location filename="../qmmpstarter.cpp" line="428"/>
         <source>Command Line Help</source>
         <translation>Opdrachtregelhulp</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="446"/>
+        <location filename="../qmmpstarter.cpp" line="441"/>
         <source>QMMP version: %1</source>
         <translation>QMMP versie: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="447"/>
+        <location filename="../qmmpstarter.cpp" line="442"/>
         <source>Compiled with Qt version: %1</source>
         <translation>Gecompileerd met QT versie: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="448"/>
+        <location filename="../qmmpstarter.cpp" line="443"/>
         <source>Using Qt version: %1</source>
         <translation>Gebruikt QT versie: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="451"/>
+        <location filename="../qmmpstarter.cpp" line="446"/>
         <source>Qmmp Version</source>
         <translation>QMMP-versie</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="468"/>
+        <location filename="../qmmpstarter.cpp" line="463"/>
         <source>User Interfaces</source>
         <translation>GebruikersInterfaces</translation>
     </message>
