@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,19 +34,23 @@ void PlayListOption::registerOprions()
     registerOption(PL_LIST, "--pl-list", tr("List all available playlists"));
     registerOption(PL_DUMP, "--pl-dump", tr("Show playlist content"), QStringList() << "id");
     registerOption(PL_PLAY, "--pl-play", tr("Play track <track> in playlist <id>"), QStringList() << "id" << "track");
-    registerOption(PL_CLEAR, "--pl-clear",  tr("Clear playlist"), QStringList() << "id");
+    registerOption(PL_CLEAR, "--pl-clear", tr("Clear playlist"), QStringList() << "id");
+    registerOption(PL_NEXT, "--pl-next", tr("Activate next playlist"));
+    registerOption(PL_PREV, "--pl-prev", tr("Activate previous playlist"));
     registerOption(PL_REPEATE_TOGGLE, "--pl-repeat-toggle", tr("Toggle playlist repeat"));
     registerOption(PL_SHUFFLE_TOGGLE, "--pl-shuffle-toggle", tr("Toggle playlist shuffle"));
     registerOption(PL_STATE, "--pl-state", tr("Show playlist options"));
 
-    setOptionFlags(PL_HELP, NO_START);
-    setOptionFlags(PL_LIST, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_DUMP, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_PLAY, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_CLEAR, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_REPEATE_TOGGLE, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_SHUFFLE_TOGGLE, HIDDEN_FROM_HELP);
-    setOptionFlags(PL_STATE, HIDDEN_FROM_HELP);
+    setOptionFlags(PL_HELP, NoStart);
+    setOptionFlags(PL_LIST, HiddenFromHelp);
+    setOptionFlags(PL_DUMP, HiddenFromHelp);
+    setOptionFlags(PL_PLAY, HiddenFromHelp);
+    setOptionFlags(PL_CLEAR, HiddenFromHelp);
+    setOptionFlags(PL_NEXT, HiddenFromHelp);
+    setOptionFlags(PL_PREV, HiddenFromHelp);
+    setOptionFlags(PL_REPEATE_TOGGLE, HiddenFromHelp);
+    setOptionFlags(PL_SHUFFLE_TOGGLE, HiddenFromHelp);
+    setOptionFlags(PL_STATE, HiddenFromHelp);
 }
 
 QString PlayListOption::shortName() const
@@ -75,11 +79,13 @@ QString PlayListOption::executeCommand(int id, const QStringList &args)
                 << helpString(PL_DUMP)
                 << helpString(PL_PLAY)
                 << helpString(PL_CLEAR)
+                << helpString(PL_NEXT)
+                << helpString(PL_PREV)
                 << helpString(PL_REPEATE_TOGGLE)
                 << helpString(PL_SHUFFLE_TOGGLE)
                 << helpString(PL_STATE);
 
-        foreach (QString line, list)
+        for(const QString &line : qAsConst(list))
             out += CommandLineManager::formatHelpString(line) + "\n";
     }
         break;
@@ -135,6 +141,28 @@ QString PlayListOption::executeCommand(int id, const QStringList &args)
         player->play();
     }
         break;
+    case PL_NEXT:
+    {
+        bool playing = SoundCore::instance()->state() == Qmmp::Playing;
+        player->stop();
+        pl_manager->selectPlayList(pl_manager->currentPlayList());
+        pl_manager->selectNextPlayList();
+        pl_manager->activateSelectedPlayList();
+        if(playing)
+            player->play();
+    }
+        break;
+    case PL_PREV:
+    {
+        bool playing = SoundCore::instance()->state() == Qmmp::Playing;
+        player->stop();
+        pl_manager->selectPlayList(pl_manager->currentPlayList());
+        pl_manager->selectPreviousPlayList();
+        pl_manager->activateSelectedPlayList();
+        if(playing)
+            player->play();
+    }
+        break;
     case PL_CLEAR:
     {
         int id = args.isEmpty() ? pl_manager->currentPlayListIndex() : args.at(0).toInt() - 1;
