@@ -16,7 +16,7 @@
     <message>
         <location filename="../playlistoption.cpp" line="35"/>
         <source>Show playlist content</source>
-        <translation type="unfinished"></translation>
+        <translation>Oynatma listesi içeriğini göster</translation>
     </message>
     <message>
         <location filename="../playlistoption.cpp" line="36"/>
@@ -26,37 +26,47 @@
     <message>
         <location filename="../playlistoption.cpp" line="37"/>
         <source>Clear playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>Çalma listesini temizle</translation>
     </message>
     <message>
         <location filename="../playlistoption.cpp" line="38"/>
-        <source>Toggle playlist repeat</source>
+        <source>Activate next playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../playlistoption.cpp" line="39"/>
-        <source>Toggle playlist shuffle</source>
+        <source>Activate previous playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../playlistoption.cpp" line="40"/>
-        <source>Show playlist options</source>
+        <source>Toggle playlist repeat</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../playlistoption.cpp" line="104"/>
-        <location filename="../playlistoption.cpp" line="126"/>
-        <location filename="../playlistoption.cpp" line="143"/>
+        <location filename="../playlistoption.cpp" line="41"/>
+        <source>Toggle playlist shuffle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../playlistoption.cpp" line="42"/>
+        <source>Show playlist options</source>
+        <translation>Oynatma listesi seçeneklerini göster</translation>
+    </message>
+    <message>
+        <location filename="../playlistoption.cpp" line="110"/>
+        <location filename="../playlistoption.cpp" line="132"/>
+        <location filename="../playlistoption.cpp" line="171"/>
         <source>Invalid playlist ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../playlistoption.cpp" line="120"/>
+        <location filename="../playlistoption.cpp" line="126"/>
         <source>Invalid number of arguments</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../playlistoption.cpp" line="130"/>
+        <location filename="../playlistoption.cpp" line="136"/>
         <source>Invalid track ID</source>
         <translation type="unfinished"></translation>
     </message>
