@@ -1,105 +1,140 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="es">
+<TS version="2.1" language="es">
 <context>
     <name>StatusOption</name>
     <message>
-        <location filename="../statusoption.cpp" line="39"/>
+        <location filename="../statusoption.cpp" line="30"/>
         <source>Print playback status</source>
         <translation>Mostrar el estado de la reproducción</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="41"/>
+        <location filename="../statusoption.cpp" line="31"/>
         <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
         <translation>Mostrar el nombre de la pista formateado (ej: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="42"/>
+        <location filename="../statusoption.cpp" line="33"/>
         <source>Print --nowplaying syntax</source>
         <translation>Mostrar sintaxis de --nowplaying</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="87"/>
+        <location filename="../statusoption.cpp" line="94"/>
         <source>Syntax:</source>
         <translation>Sintaxis:</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="88"/>
+        <location filename="../statusoption.cpp" line="95"/>
         <source>%p - artist</source>
         <translation>%p - artista</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="89"/>
+        <location filename="../statusoption.cpp" line="96"/>
         <source>%a - album</source>
         <translation>%a - álbum</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="90"/>
+        <location filename="../statusoption.cpp" line="97"/>
         <source>%aa - album artist</source>
         <translation>%aa - artista del álbum</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="91"/>
+        <location filename="../statusoption.cpp" line="98"/>
         <source>%t - title</source>
         <translation>%t - título</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="92"/>
+        <location filename="../statusoption.cpp" line="99"/>
         <source>%n - track</source>
         <translation>%n - pista</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="93"/>
+        <location filename="../statusoption.cpp" line="100"/>
         <source>%NN - 2-digit track</source>
         <translation>%NN - pista (2 dígitos)</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="94"/>
+        <location filename="../statusoption.cpp" line="101"/>
         <source>%g - genre</source>
         <translation>%g - género</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="95"/>
+        <location filename="../statusoption.cpp" line="102"/>
         <source>%c - comment</source>
         <translation>%c - comentario</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="96"/>
+        <location filename="../statusoption.cpp" line="103"/>
         <source>%C - composer</source>
         <translation>%C - compositor</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="97"/>
+        <location filename="../statusoption.cpp" line="104"/>
         <source>%D - disc number</source>
         <translation>%D - número de disco</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="98"/>
+        <location filename="../statusoption.cpp" line="105"/>
         <source>%f - file name</source>
         <translation>%f - nombre del archivo</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="99"/>
+        <location filename="../statusoption.cpp" line="106"/>
         <source>%F - full path</source>
         <translation>%F - ruta completa</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="100"/>
+        <location filename="../statusoption.cpp" line="107"/>
         <source>%y - year</source>
         <translation>%y - año</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="101"/>
+        <location filename="../statusoption.cpp" line="108"/>
         <source>%l - duration</source>
         <translation>%l - duración</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="102"/>
+        <location filename="../statusoption.cpp" line="109"/>
+        <source>%{bitrate} - bitrate</source>
+        <translation>%{bitrate} - bitrate</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="110"/>
+        <source>%{samplerate} - sample rate</source>
+        <translation>%{samplerate} - frecuencia de muestreo</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="111"/>
+        <source>%{channels} - number of channels</source>
+        <translation>%{channels} - número de canales</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="112"/>
+        <source>%{samplesize} - bits per sample</source>
+        <translation>%{samplesize} - bits por muestra</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="113"/>
+        <source>%{format} - format name</source>
+        <translation>%{format} - nombre de formato</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="114"/>
+        <source>%{decoder} - decoder name</source>
+        <translation>%{decoder} - nombre de decodificador</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="115"/>
+        <source>%{filesize} - file size</source>
+        <translation>%{filesize} - tamaño de archivo</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="116"/>
         <source>%if(A&amp;B&amp;C,D,E) - condition</source>
         <translation>%if(A&amp;B&amp;C,D,E) - condición</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="103"/>
+        <location filename="../statusoption.cpp" line="117"/>
         <source>%dir(n) - directory name located on n levels above</source>
         <translation>%dir(n) - nombre de directorio localizado sobre n niveles arriba</translation>
     </message>
