@@ -1,105 +1,140 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ja_JP">
+<TS version="2.1" language="ja_JP">
 <context>
     <name>StatusOption</name>
     <message>
-        <location filename="../statusoption.cpp" line="39"/>
+        <location filename="../statusoption.cpp" line="30"/>
         <source>Print playback status</source>
         <translation>再生の状況を表示</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="41"/>
+        <location filename="../statusoption.cpp" line="31"/>
         <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
         <translation>トラック名を整形して表示 (例: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="42"/>
+        <location filename="../statusoption.cpp" line="33"/>
         <source>Print --nowplaying syntax</source>
         <translation>--nowplaying の構文規則を表示</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="87"/>
+        <location filename="../statusoption.cpp" line="94"/>
         <source>Syntax:</source>
         <translation>構文規則:</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="88"/>
+        <location filename="../statusoption.cpp" line="95"/>
         <source>%p - artist</source>
         <translation>%p - アーティスト名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="89"/>
+        <location filename="../statusoption.cpp" line="96"/>
         <source>%a - album</source>
         <translation>%a - アルバム名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="90"/>
+        <location filename="../statusoption.cpp" line="97"/>
         <source>%aa - album artist</source>
         <translation>%aa - アルバムアーティスト名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="91"/>
+        <location filename="../statusoption.cpp" line="98"/>
         <source>%t - title</source>
         <translation>%t - 題名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="92"/>
+        <location filename="../statusoption.cpp" line="99"/>
         <source>%n - track</source>
         <translation>%n - トラック番号</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="93"/>
+        <location filename="../statusoption.cpp" line="100"/>
         <source>%NN - 2-digit track</source>
         <translation>%NN - トラック番号 数字2桁</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="94"/>
+        <location filename="../statusoption.cpp" line="101"/>
         <source>%g - genre</source>
         <translation>%g - ジャンル名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="95"/>
+        <location filename="../statusoption.cpp" line="102"/>
         <source>%c - comment</source>
         <translation>%c - コメント</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="96"/>
+        <location filename="../statusoption.cpp" line="103"/>
         <source>%C - composer</source>
         <translation>%C - 作曲者名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="97"/>
+        <location filename="../statusoption.cpp" line="104"/>
         <source>%D - disc number</source>
         <translation>%D - ディスク番号</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="98"/>
+        <location filename="../statusoption.cpp" line="105"/>
         <source>%f - file name</source>
         <translation>%f - ファイル名</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="99"/>
+        <location filename="../statusoption.cpp" line="106"/>
         <source>%F - full path</source>
         <translation>%F - 完全なファイルパス</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="100"/>
+        <location filename="../statusoption.cpp" line="107"/>
         <source>%y - year</source>
         <translation>%y - 年</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="101"/>
+        <location filename="../statusoption.cpp" line="108"/>
         <source>%l - duration</source>
         <translation>%l - 演奏時間</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="102"/>
+        <location filename="../statusoption.cpp" line="109"/>
+        <source>%{bitrate} - bitrate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="110"/>
+        <source>%{samplerate} - sample rate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="111"/>
+        <source>%{channels} - number of channels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="112"/>
+        <source>%{samplesize} - bits per sample</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="113"/>
+        <source>%{format} - format name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="114"/>
+        <source>%{decoder} - decoder name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="115"/>
+        <source>%{filesize} - file size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="116"/>
         <source>%if(A&amp;B&amp;C,D,E) - condition</source>
         <translation>%if(A&amp;B&amp;C,D,E) - 状態</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="103"/>
+        <location filename="../statusoption.cpp" line="117"/>
         <source>%dir(n) - directory name located on n levels above</source>
         <translation>%dir(n) - n 層上のディレクトリ名</translation>
     </message>
