@@ -1,105 +1,140 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ru">
+<TS version="2.1" language="ru">
 <context>
     <name>StatusOption</name>
     <message>
-        <location filename="../statusoption.cpp" line="39"/>
+        <location filename="../statusoption.cpp" line="30"/>
         <source>Print playback status</source>
         <translation>Показать статус воспроизведения</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="41"/>
+        <location filename="../statusoption.cpp" line="31"/>
         <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
         <translation>Показать форматированное название композиции (Пример: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="42"/>
+        <location filename="../statusoption.cpp" line="33"/>
         <source>Print --nowplaying syntax</source>
         <translation>Показать синтаксис команды --nowplaying</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="87"/>
+        <location filename="../statusoption.cpp" line="94"/>
         <source>Syntax:</source>
         <translation>Синтаксис:</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="88"/>
+        <location filename="../statusoption.cpp" line="95"/>
         <source>%p - artist</source>
         <translation>%p - исполнитель</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="89"/>
+        <location filename="../statusoption.cpp" line="96"/>
         <source>%a - album</source>
         <translation>%a - альбом</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="90"/>
+        <location filename="../statusoption.cpp" line="97"/>
         <source>%aa - album artist</source>
         <translation>%aa - исполнитель альбома</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="91"/>
+        <location filename="../statusoption.cpp" line="98"/>
         <source>%t - title</source>
         <translation>%t - название</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="92"/>
+        <location filename="../statusoption.cpp" line="99"/>
         <source>%n - track</source>
         <translation>%n - номер трека</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="93"/>
+        <location filename="../statusoption.cpp" line="100"/>
         <source>%NN - 2-digit track</source>
         <translation>%NN - 2-х разрядный номер трека</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="94"/>
+        <location filename="../statusoption.cpp" line="101"/>
         <source>%g - genre</source>
         <translation>%g - жанр</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="95"/>
+        <location filename="../statusoption.cpp" line="102"/>
         <source>%c - comment</source>
         <translation>%c - комментарий</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="96"/>
+        <location filename="../statusoption.cpp" line="103"/>
         <source>%C - composer</source>
         <translation>%С - композитор</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="97"/>
+        <location filename="../statusoption.cpp" line="104"/>
         <source>%D - disc number</source>
         <translation>%D - номер диска</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="98"/>
+        <location filename="../statusoption.cpp" line="105"/>
         <source>%f - file name</source>
         <translation>%f - имя файла</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="99"/>
+        <location filename="../statusoption.cpp" line="106"/>
         <source>%F - full path</source>
         <translation>%F - полный путь</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="100"/>
+        <location filename="../statusoption.cpp" line="107"/>
         <source>%y - year</source>
         <translation>%y - год</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="101"/>
+        <location filename="../statusoption.cpp" line="108"/>
         <source>%l - duration</source>
         <translation>%l - длительность</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="102"/>
+        <location filename="../statusoption.cpp" line="109"/>
+        <source>%{bitrate} - bitrate</source>
+        <translation>%{bitrate} - битовая частота</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="110"/>
+        <source>%{samplerate} - sample rate</source>
+        <translation>%{samplerate} - частота дискретизации</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="111"/>
+        <source>%{channels} - number of channels</source>
+        <translation>%{channels} - количество каналов</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="112"/>
+        <source>%{samplesize} - bits per sample</source>
+        <translation>%{samplesize} - разрядность</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="113"/>
+        <source>%{format} - format name</source>
+        <translation>%{format} - название формата</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="114"/>
+        <source>%{decoder} - decoder name</source>
+        <translation>%{decoder} - название декодера</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="115"/>
+        <source>%{filesize} - file size</source>
+        <translation>%{filesize} - размер файла</translation>
+    </message>
+    <message>
+        <location filename="../statusoption.cpp" line="116"/>
         <source>%if(A&amp;B&amp;C,D,E) - condition</source>
         <translation>%if(A&amp;B&amp;C,D,E) - условие</translation>
     </message>
     <message>
-        <location filename="../statusoption.cpp" line="103"/>
+        <location filename="../statusoption.cpp" line="117"/>
         <source>%dir(n) - directory name located on n levels above</source>
         <translation>%dir(n) - имя директории на n уровней выше</translation>
     </message>
