@@ -31,13 +31,13 @@ class SettingsDialog : public QDialog
 {
 Q_OBJECT
 public:
-    SettingsDialog(QWidget *parent = 0);
+    SettingsDialog(QWidget *parent = nullptr);
 
     ~SettingsDialog();
 
 public slots:
-    virtual void accept();
-    virtual void reject();
+    virtual void accept() override;
+    virtual void reject() override;
 
 private slots:
     void on_freqSlider_valueChanged (int value);
