@@ -26,7 +26,7 @@
     <message>
         <location filename="../effectbs2bfactory.cpp" line="56"/>
         <source>Compiled against libbs2b-%1</source>
-        <translation>libbs2b-%1 ile derlenmiştir</translation>
+        <translation>libbs2b-%1 &apos;e dayanarak derlendi</translation>
     </message>
     <message>
         <location filename="../effectbs2bfactory.cpp" line="57"/>
@@ -35,13 +35,13 @@
     </message>
     <message>
         <location filename="../effectbs2bfactory.cpp" line="58"/>
-        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
+        <translation>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
     </message>
     <message>
         <location filename="../effectbs2bfactory.cpp" line="59"/>
-        <source>Sebastian Pipping &lt;sebastian@pipping.org&gt;</source>
-        <translation type="unfinished"></translation>
+        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
+        <translation>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</translation>
     </message>
 </context>
 <context>
