@@ -37,17 +37,22 @@
         <translation>Κατάλογος εξόδου:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="59"/>
+        <location filename="../settingsdialog.ui" line="95"/>
         <source>Output file name:</source>
         <translation>Όνομα αρχείου εξόδου</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="76"/>
+        <location filename="../settingsdialog.ui" line="109"/>
+        <source>Write to single file if possible.</source>
+        <translation>Εγγραφή σε ένα αρχείο αν είναι εφικτό</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="36"/>
         <source>Quality:</source>
         <translation>Ποιότητα:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="69"/>
+        <location filename="../settingsdialog.cpp" line="71"/>
         <source>Choose a directory</source>
         <translation>Επιλογή ενός καταλόγου</translation>
     </message>
