@@ -37,17 +37,22 @@
         <translation>Diretório de destino:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="59"/>
+        <location filename="../settingsdialog.ui" line="95"/>
         <source>Output file name:</source>
         <translation>Nome do ficheiro de destino:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="76"/>
+        <location filename="../settingsdialog.ui" line="109"/>
+        <source>Write to single file if possible.</source>
+        <translation>Se possível, escrever para um único ficheiro.</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="36"/>
         <source>Quality:</source>
         <translation>Qualidade:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="69"/>
+        <location filename="../settingsdialog.cpp" line="71"/>
         <source>Choose a directory</source>
         <translation>Escolha um diretório</translation>
     </message>
