@@ -1,27 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<TS version="2.1" language="pl_PL">
 <context>
     <name>EffectSoXRFactory</name>
     <message>
-        <location filename="../effectsoxrfactory.cpp" line="31"/>
+        <location filename="../effectsoxrfactory.cpp" line="30"/>
         <source>SoX Resampler Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Wtyczka Resampler Sox</translation>
+    </message>
+    <message>
+        <location filename="../effectsoxrfactory.cpp" line="51"/>
+        <source>About SoX Resampler Plugin</source>
+        <translation>O wtyczce Resampler Sox</translation>
     </message>
     <message>
         <location filename="../effectsoxrfactory.cpp" line="52"/>
-        <source>About SoX Resampler Plugin</source>
-        <translation type="unfinished"></translation>
+        <source>Qmmp SoX Resampler Plugin</source>
+        <translation>Wtyczka Resampler Sox dla Qmmp</translation>
     </message>
     <message>
         <location filename="../effectsoxrfactory.cpp" line="53"/>
-        <source>Qmmp SoX Resampler Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../effectsoxrfactory.cpp" line="54"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
@@ -29,7 +29,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>Sample Rate Converter Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustawienia wtyczki Sample Rate Converter</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="20"/>
@@ -39,32 +39,32 @@
     <message>
         <location filename="../settingsdialog.ui" line="40"/>
         <source>Quality:</source>
-        <translation type="unfinished"></translation>
+        <translation>Jakość:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="34"/>
         <source>Quick</source>
-        <translation type="unfinished"></translation>
+        <translation>Szybka</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="35"/>
         <source>Low</source>
-        <translation type="unfinished"></translation>
+        <translation>Niska</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="36"/>
         <source>Medium</source>
-        <translation>Średnio</translation>
+        <translation>Średnia</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="37"/>
         <source>High</source>
-        <translation type="unfinished"></translation>
+        <translation>Wysoka</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="38"/>
         <source>Very High</source>
-        <translation type="unfinished"></translation>
+        <translation>Bardzo wysoka</translation>
     </message>
 </context>
 </TS>
