@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,8 +27,10 @@
 #include <QRegExp>
 #include <QSettings>
 #include <QFileInfo>
+#include <QDebug>
 #include <qmmp/trackinfo.h>
 #include <qmmp/inputsource.h>
+#include <qmmp/volumehandler.h>
 #include "mplayerengine.h"
 
 //#define MPLAYER_DEBUG
@@ -63,8 +65,8 @@ TrackInfo *MplayerInfo::createTrackInfo(const QString &path)
     mplayer_process.kill();
     QString str = QString::fromLocal8Bit(mplayer_process.readAll()).trimmed();
     TrackInfo *info = new TrackInfo(path);
-    QStringList lines = str.split("\n");
-    foreach(QString line, lines)
+    const QStringList lines = str.split("\n");
+    for(const QString &line : qAsConst(lines))
     {
         if(rx_id_length.indexIn(line) > -1)
             info->setDuration((qint64) rx_id_length.cap(1).toDouble() * 1000);
@@ -97,16 +99,7 @@ QStringList MplayerInfo::filters()
 MplayerEngine::MplayerEngine(QObject *parent)
         : AbstractEngine(parent)
 {
-    m_source = nullptr;
-    m_bitrate = 0;
-    m_samplerate = 0;
-    m_channels = 0;
-    m_bitsPerSample = 0;
-    m_length = 0;
-    m_currentTime = 0;
-    m_muted = false;
-    m_user_stop = false;
-    m_process = nullptr;
+    connect(VolumeHandler::instance(), SIGNAL(mutedChanged(bool)), SLOT(setMuted(bool)));
 }
 
 MplayerEngine::~MplayerEngine()
@@ -129,9 +122,9 @@ bool MplayerEngine::play()
 
 bool MplayerEngine::enqueue(InputSource *source)
 {
-    QStringList filters = MplayerInfo::filters();
+    const QStringList filters = MplayerInfo::filters();
     bool supports = false;
-    foreach(QString filter, filters)
+    for(const QString &filter : qAsConst(filters))
     {
         QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
         supports = regexp.exactMatch(source->path());
@@ -210,9 +203,8 @@ void MplayerEngine::setMuted(bool muted)
 
 void MplayerEngine::readStdOut()
 {
-    QString line = QString::fromLocal8Bit(m_process->readAll ()).trimmed();
-    QStringList lines = line.split("\n");
-    foreach(line, lines)
+    const QStringList lines = QString::fromLocal8Bit(m_process->readAll()).trimmed().split("\n");
+    for(const QString &line : lines)
     {
         if (rx_av.indexIn(line) > -1)
         {
@@ -282,6 +274,12 @@ void MplayerEngine::onError(QProcess::ProcessError error)
     qWarning("MplayerEngine: process error: %d", error);
 }
 
+void MplayerEngine::onStateChanged(QProcess::ProcessState state)
+{
+    if(state == QProcess::Running)
+        setMuted(VolumeHandler::instance()->isMuted());
+}
+
 void MplayerEngine::startMplayerProcess()
 {
     initialize();
@@ -290,6 +288,7 @@ void MplayerEngine::startMplayerProcess()
     m_process = new QProcess(this);
     connect(m_process, SIGNAL(readyReadStandardOutput()), SLOT(readStdOut()));
     connect(m_process, SIGNAL(error(QProcess::ProcessError)), SLOT(onError(QProcess::ProcessError)));
+    connect(m_process, SIGNAL(stateChanged(QProcess::ProcessState)), SLOT(onStateChanged(QProcess::ProcessState)));
     m_process->start ("mplayer", m_args);
     StateHandler::instance()->dispatch(Qmmp::Playing);
     StateHandler::instance()->dispatch(m_length);
@@ -299,6 +298,4 @@ void MplayerEngine::startMplayerProcess()
     m_source->deleteLater();
     m_source = nullptr;
     m_currentTime = 0;
-    if(m_muted)
-        setMuted(true);
 }
