@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,7 @@
 #include "mplayermetadatamodel.h"
 
 MplayerMetaDataModel::MplayerMetaDataModel(const QString &path)
-    : MetaDataModel(true, MetaDataModel::COMPLETE_PROPERTY_LIST)
+    : MetaDataModel(true, MetaDataModel::CompletePropertyList)
 {
     m_path = path;
 }
@@ -52,11 +52,11 @@ QList<MetaDataItem> MplayerMetaDataModel::extraProperties() const
     mplayer_process.start("mplayer", args);
     mplayer_process.waitForFinished();
     QString str = QString::fromLocal8Bit(mplayer_process.readAll()).trimmed();
-    QStringList lines = str.split("\n");
+    const QStringList lines = str.split("\n");
     //mplayer std output parsing
     QRegExp rx_id("^(ID_.*)=(.*)");
     QMap<QString, QString> params;
-    foreach(QString line, lines)
+    for(const QString &line : qAsConst(lines))
     {
         if(rx_id.indexIn(line.trimmed()) > -1)
             params.insert(rx_id.cap(1), rx_id.cap(2));
