@@ -30,13 +30,13 @@ class SettingsDialog : public QDialog
 {
 Q_OBJECT
 public:
-    SettingsDialog(QWidget *parent = 0);
+    SettingsDialog(QWidget *parent = nullptr);
 
     ~SettingsDialog();
 
 
 public slots:
-    virtual void accept();
+    virtual void accept() override;
 
 private:
     Ui::SettingsDialog m_ui;
