@@ -54,7 +54,7 @@
     <message>
         <location filename="../mplayermetadatamodel.cpp" line="67"/>
         <source>Video format</source>
-        <translation>Formato Video</translation>
+        <translation>Formato video</translation>
     </message>
     <message>
         <location filename="../mplayermetadatamodel.cpp" line="68"/>
@@ -74,7 +74,7 @@
     <message>
         <location filename="../mplayermetadatamodel.cpp" line="71"/>
         <source>Video bitrate</source>
-        <translation>bit al secondo Video</translation>
+        <translation>bit al secondo video</translation>
     </message>
     <message>
         <location filename="../mplayermetadatamodel.cpp" line="71"/>
