@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_CN">
+<TS version="2.1" language="zh_CN">
 <context>
     <name>MplayerEngineFactory</name>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="34"/>
+        <location filename="../mplayerenginefactory.cpp" line="33"/>
         <source>Mplayer Plugin</source>
         <translation>Mplayer 插件</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="37"/>
+        <location filename="../mplayerenginefactory.cpp" line="36"/>
         <source>Video Files</source>
         <translation>视频文件</translation>
     </message>
@@ -37,72 +37,78 @@
 <context>
     <name>MplayerMetaDataModel</name>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
+        <location filename="../mplayermetadatamodel.cpp" line="39"/>
         <source>Size</source>
         <translation>大小：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
-        <source>KB</source>
-        <translation>千字节</translation>
+        <location filename="../mplayermetadatamodel.cpp" line="39"/>
+        <source>KiB</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="75"/>
-        <source>Length</source>
-        <translation>长度：</translation>
-    </message>
-    <message>
-        <location filename="../mplayermetadatamodel.cpp" line="77"/>
+        <location filename="../mplayermetadatamodel.cpp" line="65"/>
         <source>Demuxer</source>
         <translation>流分离：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="80"/>
+        <location filename="../mplayermetadatamodel.cpp" line="67"/>
         <source>Video format</source>
         <translation>视频格式</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="82"/>
+        <location filename="../mplayermetadatamodel.cpp" line="68"/>
         <source>FPS</source>
         <translation>帧每秒</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="84"/>
+        <location filename="../mplayermetadatamodel.cpp" line="69"/>
         <source>Video codec</source>
         <translation>视频编码</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="86"/>
+        <location filename="../mplayermetadatamodel.cpp" line="70"/>
         <source>Aspect ratio</source>
         <translation>宽高比：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="88"/>
+        <location filename="../mplayermetadatamodel.cpp" line="71"/>
         <source>Video bitrate</source>
         <translation>视频比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="95"/>
+        <location filename="../mplayermetadatamodel.cpp" line="71"/>
+        <location filename="../mplayermetadatamodel.cpp" line="76"/>
+        <source>kbps</source>
+        <translation>千比特每秒</translation>
+    </message>
+    <message>
+        <location filename="../mplayermetadatamodel.cpp" line="74"/>
         <source>Audio codec</source>
         <translation>音频编码</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="97"/>
+        <location filename="../mplayermetadatamodel.cpp" line="75"/>
         <source>Sample rate</source>
         <translation>取样率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="99"/>
+        <location filename="../mplayermetadatamodel.cpp" line="75"/>
+        <source>Hz</source>
+        <translation>赫兹</translation>
+    </message>
+    <message>
+        <location filename="../mplayermetadatamodel.cpp" line="76"/>
         <source>Audio bitrate</source>
         <translation>音频比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="101"/>
+        <location filename="../mplayermetadatamodel.cpp" line="77"/>
         <source>Channels</source>
         <translation>声音通道</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="103"/>
+        <location filename="../mplayermetadatamodel.cpp" line="72"/>
         <source>Resolution</source>
         <translation>分辨率</translation>
     </message>
