@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_TW">
+<TS version="2.1" language="zh_TW">
 <context>
     <name>MplayerEngineFactory</name>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="34"/>
+        <location filename="../mplayerenginefactory.cpp" line="33"/>
         <source>Mplayer Plugin</source>
         <translation>Mplayer 外掛</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="37"/>
+        <location filename="../mplayerenginefactory.cpp" line="36"/>
         <source>Video Files</source>
         <translation>視頻文件</translation>
     </message>
@@ -31,78 +31,84 @@
     <message>
         <location filename="../mplayerenginefactory.cpp" line="86"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
     <name>MplayerMetaDataModel</name>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
+        <location filename="../mplayermetadatamodel.cpp" line="39"/>
         <source>Size</source>
         <translation>大小：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
-        <source>KB</source>
-        <translation>KB</translation>
+        <location filename="../mplayermetadatamodel.cpp" line="39"/>
+        <source>KiB</source>
+        <translation>KiB</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="75"/>
-        <source>Length</source>
-        <translation>長度</translation>
-    </message>
-    <message>
-        <location filename="../mplayermetadatamodel.cpp" line="77"/>
+        <location filename="../mplayermetadatamodel.cpp" line="65"/>
         <source>Demuxer</source>
         <translation>流分離</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="80"/>
+        <location filename="../mplayermetadatamodel.cpp" line="67"/>
         <source>Video format</source>
         <translation>視頻格式</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="82"/>
+        <location filename="../mplayermetadatamodel.cpp" line="68"/>
         <source>FPS</source>
         <translation>FPS</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="84"/>
+        <location filename="../mplayermetadatamodel.cpp" line="69"/>
         <source>Video codec</source>
         <translation>視頻編碼</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="86"/>
+        <location filename="../mplayermetadatamodel.cpp" line="70"/>
         <source>Aspect ratio</source>
         <translation>寬高比：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="88"/>
+        <location filename="../mplayermetadatamodel.cpp" line="71"/>
         <source>Video bitrate</source>
         <translation>視頻比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="95"/>
+        <location filename="../mplayermetadatamodel.cpp" line="71"/>
+        <location filename="../mplayermetadatamodel.cpp" line="76"/>
+        <source>kbps</source>
+        <translation>kbps</translation>
+    </message>
+    <message>
+        <location filename="../mplayermetadatamodel.cpp" line="74"/>
         <source>Audio codec</source>
         <translation>音頻編碼</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="97"/>
+        <location filename="../mplayermetadatamodel.cpp" line="75"/>
         <source>Sample rate</source>
         <translation>取樣率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="99"/>
+        <location filename="../mplayermetadatamodel.cpp" line="75"/>
+        <source>Hz</source>
+        <translation>Hz</translation>
+    </message>
+    <message>
+        <location filename="../mplayermetadatamodel.cpp" line="76"/>
         <source>Audio bitrate</source>
         <translation>音頻比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="101"/>
+        <location filename="../mplayermetadatamodel.cpp" line="77"/>
         <source>Channels</source>
         <translation>音頻通道</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="103"/>
+        <location filename="../mplayermetadatamodel.cpp" line="72"/>
         <source>Resolution</source>
         <translation>分辨率</translation>
     </message>
