@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="nl">
+<TS version="2.1" language="nl">
 <context>
     <name>QmmpFileDialog</name>
     <message>
@@ -19,7 +19,7 @@
         <location filename="../qmmpfiledialog.ui" line="212"/>
         <location filename="../qmmpfiledialog.ui" line="237"/>
         <source>...</source>
-        <translation></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="190"/>
@@ -60,18 +60,18 @@
 <context>
     <name>QmmpFileDialogFactory</name>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="70"/>
-        <location filename="../qmmpfiledialog.cpp" line="80"/>
+        <location filename="../qmmpfiledialog.cpp" line="69"/>
+        <location filename="../qmmpfiledialog.cpp" line="79"/>
         <source>Qmmp File Dialog</source>
         <translation>Qmmp Bestandsdialoog</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="79"/>
+        <location filename="../qmmpfiledialog.cpp" line="78"/>
         <source>About Qmmp File Dialog</source>
         <translation>Over de Qmmp Bestandsdialoog</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="81"/>
+        <location filename="../qmmpfiledialog.cpp" line="80"/>
         <source>Written by:
 Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
@@ -80,7 +80,7 @@ Vladimír Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="84"/>
+        <location filename="../qmmpfiledialog.cpp" line="83"/>
         <source>Some code is copied from the Qt library</source>
         <translation>Sommige code is gekopiëerd van de Qt bibliotheek</translation>
     </message>
