@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu_HU">
+<TS version="2.1" language="hu">
 <context>
     <name>TwoPanelFileDialog</name>
     <message>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../twopanelfiledialog.ui" line="117"/>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Lejátszás</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="130"/>
@@ -37,23 +37,23 @@
 <context>
     <name>TwoPanelFileDialogFactory</name>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="68"/>
-        <location filename="../twopanelfiledialog.cpp" line="78"/>
+        <location filename="../twopanelfiledialog.cpp" line="67"/>
+        <location filename="../twopanelfiledialog.cpp" line="77"/>
         <source>Two-panel File Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="77"/>
+        <location filename="../twopanelfiledialog.cpp" line="76"/>
         <source>About Two-panel File Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="79"/>
+        <location filename="../twopanelfiledialog.cpp" line="78"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="80"/>
+        <location filename="../twopanelfiledialog.cpp" line="79"/>
         <source>Based on code from the Qt library</source>
         <translation type="unfinished"></translation>
     </message>
