@@ -1,59 +1,59 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sr_RS">
+<TS version="2.1" language="sr_RS">
 <context>
     <name>TwoPanelFileDialog</name>
     <message>
         <location filename="../twopanelfiledialog.ui" line="14"/>
         <source>Add Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Додавање фајлова</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="70"/>
         <source>File name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Име фајла:</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="80"/>
         <source>Files of type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Типови фајлова:</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="117"/>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Пусти</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="130"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Додај</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialog.ui" line="143"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Затвори</translation>
     </message>
 </context>
 <context>
     <name>TwoPanelFileDialogFactory</name>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="68"/>
-        <location filename="../twopanelfiledialog.cpp" line="78"/>
+        <location filename="../twopanelfiledialog.cpp" line="67"/>
+        <location filename="../twopanelfiledialog.cpp" line="77"/>
         <source>Two-panel File Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="77"/>
+        <location filename="../twopanelfiledialog.cpp" line="76"/>
         <source>About Two-panel File Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="79"/>
+        <location filename="../twopanelfiledialog.cpp" line="78"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../twopanelfiledialog.cpp" line="80"/>
+        <location filename="../twopanelfiledialog.cpp" line="79"/>
         <source>Based on code from the Qt library</source>
         <translation type="unfinished"></translation>
     </message>
@@ -64,23 +64,24 @@
         <location filename="../twopanelfiledialogimpl.cpp" line="322"/>
         <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Додај</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialogimpl.cpp" line="340"/>
         <source>Directories</source>
-        <translation type="unfinished"></translation>
+        <translation>Фасцикле</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialogimpl.cpp" line="352"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Сачувај</translation>
     </message>
     <message>
         <location filename="../twopanelfiledialogimpl.cpp" line="459"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 већ постоји.
+Желите ли да га пребришете?</translation>
     </message>
 </context>
 </TS>
