@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,12 +34,7 @@
 #include "converter.h"
 
 Converter::Converter(QObject *parent) : QObject(parent), QRunnable()
-{
-    m_user_stop = false;
-    m_decoder = nullptr;
-    m_input = nullptr;
-    m_row = -1;
-}
+{}
 
 Converter::~Converter()
 {
@@ -152,6 +147,9 @@ void Converter::run()
 
 
     QString name = formatter.format(info);
+    name.remove("'");
+    name.remove("\"");
+    name.remove(":");
     QString full_path = out_path + "/" + name + "." + m_preset["ext"].toString();
 
     if(QFile::exists(full_path))
@@ -267,7 +265,11 @@ void Converter::run()
             if(full_path.endsWith(".mp3", Qt::CaseInsensitive))
             {
                 TagLib::MPEG::File *mpeg_file = dynamic_cast <TagLib::MPEG::File *> (file.file());
+#if ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION <= 11))
                 mpeg_file->save(TagLib::MPEG::File::ID3v2, true);
+#else
+                mpeg_file->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers);
+#endif
             }
             else
                 file.save();
@@ -307,7 +309,7 @@ bool Converter::convert(Decoder *decoder, FILE *file, bool use16bit)
     int outSampleSize = AudioParameters::sampleSize(outFormat);
 
     unsigned char input_buffer[QMMP_BLOCK_FRAMES * ap.frameSize() * 4];
-    float converter_buffer[QMMP_BLOCK_FRAMES * ap.channels() * 4];
+    float converter_buffer[QMMP_BLOCK_FRAMES * ap.channels() * sizeof(float)];
     unsigned char output_buffer[QMMP_BLOCK_FRAMES * outSampleSize * ap.channels() * 4];
 
     emit progress(0);
