@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,6 @@
 #include <QMessageBox>
 #include <QFile>
 #include <QDir>
-#include <QProcess>
 #include <qmmp/soundcore.h>
 #include <qmmpui/uihelper.h>
 #include <qmmpui/playlistmodel.h>
@@ -65,7 +64,7 @@ void CopyPaste::cut()
     qDebug("%s", Q_FUNC_INFO);
     qDeleteAll(m_buffer);
     m_buffer.clear();
-    foreach(PlayListTrack *track,  m_pl_manager->selectedPlayList()->selectedTracks())
+    for(PlayListTrack *track : m_pl_manager->selectedPlayList()->selectedTracks())
     {
         m_buffer.append(new PlayListTrack(*track));
     }
@@ -77,7 +76,7 @@ void CopyPaste::copy()
     qDebug("%s", Q_FUNC_INFO);
     qDeleteAll(m_buffer);
     m_buffer.clear();
-    foreach(PlayListTrack *track,  m_pl_manager->selectedPlayList()->selectedTracks())
+    for(PlayListTrack *track : m_pl_manager->selectedPlayList()->selectedTracks())
     {
         m_buffer.append(new PlayListTrack(*track));
     }
@@ -86,7 +85,7 @@ void CopyPaste::copy()
 void CopyPaste::paste()
 {
     qDebug("%s", Q_FUNC_INFO);
-    foreach(PlayListTrack *track,  m_buffer)
+    for(const PlayListTrack *track : qAsConst(m_buffer))
     {
         m_pl_manager->selectedPlayList()->add(new PlayListTrack(*track));
     }
