@@ -23,7 +23,7 @@
 #include "copypaste.h"
 #include "copypastefactory.h"
 
-const GeneralProperties CopyPasteFactory::properties() const
+GeneralProperties CopyPasteFactory::properties() const
 {
     GeneralProperties properties;
     properties.name = tr("Copy/Paste Plugin");
@@ -41,7 +41,7 @@ QObject *CopyPasteFactory::create(QObject *parent)
 
 QDialog *CopyPasteFactory::createConfigDialog(QWidget *)
 {
-    return 0;
+    return nullptr;
 }
 
 void CopyPasteFactory::showAbout(QWidget *parent)
@@ -52,10 +52,7 @@ void CopyPasteFactory::showAbout(QWidget *parent)
                         tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
-QTranslator *CopyPasteFactory::createTranslator(QObject *parent)
+QString CopyPasteFactory::translation() const
 {
-    QTranslator *translator = new QTranslator(parent);
-    QString locale = Qmmp::systemLanguageID();
-    translator->load(QString(":/copypaste_plugin_") + locale);
-    return translator;
+    return QLatin1String(":/copypaste_plugin_");
 }
