@@ -115,7 +115,7 @@ void FileOps::execAction(int n)
         if (PlayListManager::instance()->selectedPlayList() != model)
             break;
 
-        foreach(PlayListTrack *track, tracks)
+        for(PlayListTrack *track : qAsConst(tracks))
         {
             if (PlayListManager::instance()->selectedPlayList() != model)
                 break;
@@ -156,7 +156,7 @@ void FileOps::copy(const QList<PlayListTrack *> &tracks, const QString &dest, co
     progress.show();
     progress.setAutoClose (false);
     int i  = 0;
-    foreach(PlayListTrack *track, tracks)
+    for(PlayListTrack *track : qAsConst(tracks))
     {
         if (!isValid(track) || !QFile::exists(track->path()))
             continue;
@@ -214,7 +214,7 @@ void FileOps::copy(const QList<PlayListTrack *> &tracks, const QString &dest, co
 
 void FileOps::rename(const QList<PlayListTrack *> &tracks, const MetaDataFormatter *formatter, PlayListModel *model)
 {
-    foreach(PlayListTrack *track, tracks)
+    for(PlayListTrack *track : qAsConst(tracks))
     {
         if (!isValid(track) || !QFile::exists(track->path())) //is it file?
             continue;
@@ -250,7 +250,7 @@ void FileOps::move(const QList<PlayListTrack *> &tracks, const QString &dest, co
     progress.show();
     progress.setAutoClose (false);
     int i  = 0;
-    foreach(PlayListTrack *track, tracks)
+    for(PlayListTrack *track : qAsConst(tracks))
     {
         if (!isValid(track) || !QFile::exists(track->path()))
             continue;
