@@ -23,9 +23,9 @@
     <message numerus="yes">
         <location filename="../fileops.cpp" line="138"/>
         <source>Are you sure you want to move %n file(s)?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Weet je zeker dat je %n bestand wilt verplaatsen?</numerusform>
+            <numerusform>Weet je zeker dat je %n bestanden wilt verplaatsen?</numerusform>
         </translation>
     </message>
     <message>
