@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,9 +46,9 @@ HalPlugin::HalPlugin(QObject *parent) : QObject(parent)
     m_addTracks = false; //do not load tracks on startup
     m_addFiles = false;
     //find existing devices
-    QStringList udis = m_manager->findDeviceByCapability("volume");
-    foreach(QString udi, udis)
-    addDevice(udi);
+    const QStringList udis = m_manager->findDeviceByCapability("volume");
+    for(const QString &udi : qAsConst(udis))
+        addDevice(udi);
     //load remaining settings
     m_addTracks = settings.value("add_tracks", false).toBool();
     m_removeTracks = settings.value("remove_tracks", false).toBool();
@@ -63,22 +63,27 @@ HalPlugin::~HalPlugin()
 
 void HalPlugin::removeDevice(const QString &udi)
 {
-    foreach(HalDevice *device, m_devices)
+    QList<HalDevice *>::iterator it = m_devices.begin();
+    while(it != m_devices.end())
     {
-        if (device->udi() == udi)
+        if((*it)->udi() == udi)
         {
-            m_devices.removeAll(device);
-            delete device;
+            delete *it;
+            it = m_devices.erase(it);
             qDebug("HalPlugin: device \"%s\" removed", qPrintable(udi));
             updateActions();
             break;
         }
+        else
+        {
+            ++it;
+        }
     }
 }
 
 void HalPlugin::addDevice(const QString &udi)
 {
-    foreach(HalDevice *device, m_devices) //is it already exists?
+    for(const HalDevice *device : qAsConst(m_devices)) //is it already exists?
     {
         if (device->udi() == udi)
             return;
@@ -141,7 +146,7 @@ void HalPlugin::addDevice(const QString &udi)
 void HalPlugin::updateActions()
 {
     // add action for cd audio or mounted volume
-    foreach(HalDevice *device, m_devices)
+    for(HalDevice *device : qAsConst(m_devices))
     {
         QStringList caps = device->property("info.capabilities").toStringList();
         QString dev_path;
@@ -184,7 +189,7 @@ void HalPlugin::updateActions()
         }
     }
     // remove action if device is unmounted/removed
-    foreach(QAction *action, m_actions->actions ())
+    for(QAction *action :m_actions->actions ())
     {
         if (!findDevice(action))
         {
@@ -205,7 +210,7 @@ void HalPlugin::processAction(QAction *action)
 
 QAction *HalPlugin::findAction(const QString &dev_path)
 {
-    foreach(QAction *action, m_actions->actions ())
+    for(QAction *action : m_actions->actions())
     {
         if (action->data().toString() == dev_path)
             return action;
@@ -215,7 +220,7 @@ QAction *HalPlugin::findAction(const QString &dev_path)
 
 HalDevice *HalPlugin::findDevice(QAction *action)
 {
-    foreach(HalDevice *device, m_devices)
+    for(HalDevice *device : qAsConst(m_devices))
     {
         QStringList caps = device->property("info.capabilities").toStringList();
         QString dev_path;
@@ -239,11 +244,11 @@ void HalPlugin::addPath(const QString &path)
 {
     PlayListModel *model = PlayListManager::instance()->selectedPlayList();
 
-    foreach(PlayListItem *item, model->items()) // Is it already exist?
+    for(const PlayListItem *item : model->items()) // Is it already exist?
     {
         if(item->isGroup())
             continue;
-        if (dynamic_cast<PlayListTrack *>(item)->path().startsWith(path))
+        if (dynamic_cast<const PlayListTrack *>(item)->path().startsWith(path))
             return;
     }
 
