@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,7 +38,7 @@ void HotkeyDialog::keyPressEvent (QKeyEvent *event)
 {
     m_key = HotkeyManager::keycodeToKeysym(event->nativeScanCode ());
     m_modifiers = event->nativeModifiers ();
-    foreach(long mask_mod, HotkeyManager::ignModifiersList())
+    for(long mask_mod : HotkeyManager::ignModifiersList())
         m_modifiers &= ~mask_mod; //remove ignored modifiers (num lock, caps lock, etc)
 
     m_ui.keyLineEdit->setText(HotkeyManager::getKeyString(m_key, m_modifiers));
