@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2009-2014 by Ilya Kotov                                 *
- *   forkotov02@hotmail.ru                                                 *
+ *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,19 +26,19 @@
 #include "ui_settingsdialog.h"
 
 /**
-    @author Ilya Kotov <forkotov02@hotmail.ru>
+    @author Ilya Kotov <forkotov02@ya.ru>
 */
 class SettingsDialog : public QDialog
 {
 Q_OBJECT
 public:
-    SettingsDialog(QWidget *parent = 0);
+    SettingsDialog(QWidget *parent = nullptr);
 
     ~SettingsDialog();
 
 
 public slots:
-    virtual void accept();
+    virtual void accept() override;
 
 private slots:
     void on_tableWidget_itemDoubleClicked (QTableWidgetItem * item);
