@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="he">
+<TS version="2.1" language="he">
 <context>
     <name>KdeNotify</name>
     <message>
-        <location filename="../kdenotify.cpp" line="121"/>
+        <location filename="../kdenotify.cpp" line="122"/>
         <source>Qmmp now playing:</source>
         <translation>Qmmp מנגן כעת:</translation>
     </message>
@@ -12,21 +12,19 @@
 <context>
     <name>KdeNotifyFactory</name>
     <message>
-        <location filename="../kdenotifyfactory.cpp" line="31"/>
-        <source>KDE 4 notification plugin</source>
-        <translation>תוספת התראת KDE 4</translation>
+        <location filename="../kdenotifyfactory.cpp" line="29"/>
+        <source>KDE notification plugin</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../kdenotifyfactory.cpp" line="51"/>
+        <location filename="../kdenotifyfactory.cpp" line="49"/>
         <source>About KDE Notification Plugin</source>
-        <translation>אודות תוספת התראת KDE 4</translation>
+        <translation>אודות תוסף התראת KDE 4</translation>
     </message>
     <message>
-        <location filename="../kdenotifyfactory.cpp" line="52"/>
-        <source>KDE 4 notification plugin for Qmmp 
-</source>
-        <translation>תוספת התראת KDE 4 עבור Qmmp 
-</translation>
+        <location filename="../kdenotifyfactory.cpp" line="50"/>
+        <source>KDE notification plugin for Qmmp</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -34,7 +32,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>KDE 4 Notification Plugin Settings</source>
-        <translation>הגדרות תוספת התראה KDE 4</translation>
+        <translation>הגדרות תוסף התראה KDE 4</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="39"/>
@@ -43,26 +41,31 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="45"/>
-        <source>Notification delay [s]:</source>
-        <translation>שיהוי התראה [ש]:</translation>
+        <source>Notification delay:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="75"/>
+        <location filename="../settingsdialog.ui" line="52"/>
+        <source>s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="78"/>
         <source>Update visible notification instead create new</source>
         <translation>עדכן התראות נראות במקום ליצור חדשות</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="85"/>
+        <location filename="../settingsdialog.ui" line="88"/>
         <source>Appearance</source>
         <translation>הופעה</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="91"/>
+        <location filename="../settingsdialog.ui" line="94"/>
         <source>Show covers</source>
         <translation>הצג כיסויים</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="100"/>
+        <location filename="../settingsdialog.ui" line="103"/>
         <source>Edit template</source>
         <translation>ערוך תבנית</translation>
     </message>
