@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2024 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   Based on Amarok 2 Ultimate Lyrics script                              *
@@ -22,15 +22,13 @@
  ***************************************************************************/
 
 #include <QtDebug>
+#include <QRegularExpression>
 #include <QTextCodec>
-#include <QRegExp>
 #include <qmmp/trackinfo.h>
 #include "lyricsprovider.h"
 
 LyricsProvider::LyricsProvider()
-{
-    m_skipRules = false;
-}
+{}
 
 void LyricsProvider::setName(const QString &name)
 {
@@ -42,6 +40,11 @@ void LyricsProvider::setTitle(const QString &title)
     m_title = title;
 }
 
+void LyricsProvider::setCharset(const QString &charset)
+{
+    m_charset = charset;
+}
+
 void LyricsProvider::setUrl(const QString &url)
 {
     m_url = url;
@@ -49,16 +52,13 @@ void LyricsProvider::setUrl(const QString &url)
 
 void LyricsProvider::addUrlFormat(const QString &replace, const QString &with)
 {
-    UrlFormat f;
-    f.replace = replace;
-    f.with = with;
-    m_urlFormats << f;
+    m_urlFormats << UrlFormat{ .replace = replace, .with = with };
 }
 
 void LyricsProvider::addRule(const QList<QPair<QString, QString> > &args, bool exclude)
 {
     Rule rule;
-    foreach(Arg i, args)
+    for(const QPair<QString, QString> &i : qAsConst(args))
     {
         Item item;
         if(!i.first.isEmpty() && !i.second.isEmpty())
@@ -96,10 +96,10 @@ QString LyricsProvider::getUrl(const TrackInfo &track) const
     {
         QString value = it.value();
 
-        foreach(const UrlFormat &format, m_urlFormats)
-            value.replace(QRegExp(QString("[%1]").arg(QRegExp::escape(format.replace))), format.with);
+        for(const UrlFormat &format: m_urlFormats)
+            value.replace(QRegularExpression(QString("[%1]").arg(QRegularExpression::escape(format.replace))), format.with);
 
-        url.replace(it.key(), value);
+        url.replace(it.key(), it.value());
 
         it++;
     }
@@ -109,10 +109,14 @@ QString LyricsProvider::getUrl(const TrackInfo &track) const
 
 QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) const
 {
-    const QString content = QString::fromUtf8(data.constData());
+    QTextCodec *codec = QTextCodec::codecForName(m_charset.toLatin1().constData());
+    if(!codec)
+        codec = QTextCodec::codecForName("UTF-8");
+
+    const QString content = codec->toUnicode(data);
     QString out;
 
-    foreach(const QString &indicator, m_invalidIndicators)
+    for(const QString &indicator : qAsConst(m_invalidIndicators))
     {
         if(content.contains(indicator))
             return QString();
@@ -123,18 +127,18 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
 
     const QMap<QString, QString> replaceMap = generateReplaceMap(track);
 
-    foreach(const Rule &rule, m_extractRules)
+    for(const Rule &rule : qAsConst(m_extractRules))
     {
         Rule tmpRule = rule;
         QString tmpContent = content;
 
-        for(int i = 0; i < tmpRule.size(); i++)
+        for(Item &item : tmpRule)
         {
             QMap<QString, QString>::const_iterator it = replaceMap.constBegin();
             while(it != replaceMap.constEnd())
             {
-                tmpRule[i].begin.replace(it.key(), it.value());
-                tmpRule[i].url.replace(it.key(), it.value());
+                item.begin.replace(it.key(), it.value());
+                item.url.replace(it.key(), it.value());
                 it++;
             }
         }
@@ -143,7 +147,7 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
 
         if(!tmpContent.isEmpty())
         {
-            foreach(const Rule &excludeRule, m_excludeRules)
+            for(const Rule &excludeRule : qAsConst(m_excludeRules))
                 tmpContent = exclude(tmpContent, excludeRule);
         }
         if(tmpContent.isEmpty())
@@ -169,10 +173,6 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
         out = out.trimmed();
     }
 
-    //plain text support
-    if(out.contains(QChar('\n')) && !out.contains(QChar('<')))
-        out.replace(QChar('\n'), QString("<br>"));
-
     return out;
 }
 
@@ -205,20 +205,22 @@ QString LyricsProvider::fixCase(const QString &title) const
 
 QMap<QString, QString> LyricsProvider::generateReplaceMap(const TrackInfo &track) const
 {
-    QMap<QString, QString> replaceMap;
-    replaceMap.insert("{artist}", track.value(Qmmp::ARTIST).toLower());
-    replaceMap.insert("{artist2}", track.value(Qmmp::ARTIST).toLower().remove(' '));
-    replaceMap.insert("{Artist}", track.value(Qmmp::ARTIST));
-    replaceMap.insert("{ARTIST}", track.value(Qmmp::ARTIST).toUpper());
-    replaceMap.insert("{a}", track.value(Qmmp::ARTIST).left(1).toLower());
-    replaceMap.insert("{album}", track.value(Qmmp::ALBUM).toLower());
-    replaceMap.insert("{album2}", track.value(Qmmp::ALBUM).toLower().remove(' '));
-    replaceMap.insert("{Album}", track.value(Qmmp::ALBUM));
-    replaceMap.insert("{title}",  track.value(Qmmp::TITLE).toLower());
-    replaceMap.insert("{Title}", track.value(Qmmp::TITLE));
-    replaceMap.insert("{Title2}", fixCase(track.value(Qmmp::TITLE)));
-    replaceMap.insert("{track}", track.value(Qmmp::TRACK));
-    replaceMap.insert("{year}",  track.value(Qmmp::YEAR));
+    QMap<QString, QString> replaceMap = {
+        { "{artist}", track.value(Qmmp::ARTIST).toLower() },
+        { "{artist2}", track.value(Qmmp::ARTIST).toLower().remove(' ') },
+        { "{Artist}", track.value(Qmmp::ARTIST) },
+        { "{ARTIST}", track.value(Qmmp::ARTIST).toUpper() },
+        { "{a}", track.value(Qmmp::ARTIST).left(1).toLower() },
+        { "{album}", track.value(Qmmp::ALBUM).toLower() },
+        { "{album2}", track.value(Qmmp::ALBUM).toLower().remove(' ') },
+        { "{Album}", track.value(Qmmp::ALBUM) },
+        { "{title}",  track.value(Qmmp::TITLE).toLower() },
+        { "{Title}", track.value(Qmmp::TITLE) },
+        { "{Title2}", fixCase(track.value(Qmmp::TITLE)) },
+        { "{track}", track.value(Qmmp::TRACK) },
+        { "{year}",  track.value(Qmmp::YEAR) }
+    };
+
     return replaceMap;
 }
 
@@ -226,7 +228,7 @@ QString LyricsProvider::extract(const QString &content, const Rule &rule) const
 {
     QString out = content;
 
-    foreach(const Item &item, rule)
+    for(const Item &item : qAsConst(rule))
     {
         if(!item.url.isEmpty())
         {
@@ -237,9 +239,9 @@ QString LyricsProvider::extract(const QString &content, const Rule &rule) const
         }
         else if(!item.tag.isEmpty())
         {
-            const QRegExp re("<(\\w+).*>");
-            re.indexIn(item.tag);
-            out = out.section(item.tag, 1).section(QString("</%1>").arg(re.cap(1)), 0, 0);
+            const QRegularExpression re("<(\\w+).*>");
+            QRegularExpressionMatch m = re.match(item.tag);
+            out = out.section(item.tag, 1).section(QString("</%1>").arg(m.captured(1)), 0, 0);
         }
         else
         {
@@ -253,22 +255,17 @@ QString LyricsProvider::exclude(const QString &content, const LyricsProvider::Ru
 {
     QString out = content;
 
-    foreach(const Item &item, rule)
+    for(const Item &item : qAsConst(rule))
     {
         if(!item.tag.isEmpty())
         {
-            const QRegExp re("<(\\w+).*>");
-            re.indexIn(item.tag);
-            out = out.section(item.tag, 0, 0) + out.section(item.tag, 1).section(QString("</%1>").arg(re.cap(1)), 1);
+            const QRegularExpression re("<(\\w+).*>");
+            QRegularExpressionMatch m = re.match(item.tag);
+            out = out.section(item.tag, 0, 0) + out.section(item.tag, 1).section(QString("</%1>").arg(m.captured(1)), 1);
         }
         else
         {
-            QString prev;
-            while(prev != out)
-            {
-                prev = out;
-                out = out.section(item.begin, 0, 0) + out.section(item.begin, 1).section(item.end, 1);
-            }
+            out = out.section(item.begin, 0, 0) + out.section(item.begin, 1).section(item.end, 1);
         }
     }
     return out.trimmed();
