@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2024 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   Based on Amarok 2 Ultimate Lyrics script                              *
@@ -25,10 +25,8 @@
 #define LYRICSPROVIDER_H
 
 #include <QString>
-#include <QStringList>
 #include <QList>
 #include <QMap>
-#include <QPair>
 
 class PlayListTrack;
 class TrackInfo;
@@ -40,6 +38,7 @@ public:
 
     void setName(const QString &name);
     void setTitle(const QString &title);
+    void setCharset(const QString &charset);
     void setUrl(const QString &url);
     void addUrlFormat(const QString &replace, const QString &with);
     void addRule(const QList<QPair<QString, QString> > &args, bool exclude = false);
@@ -69,14 +68,13 @@ private:
     QString exclude(const QString &content, const Rule &rule) const;
 
     QString m_name, m_title;
+    QString m_charset = QLatin1String("utf-8");
     QString m_url;
     QList<UrlFormat> m_urlFormats;
     QList<Rule> m_extractRules;
     QList<Rule> m_excludeRules;
     QStringList m_invalidIndicators;
-    bool m_skipRules;
-
-    typedef QPair<QString, QString> Arg;
+    bool m_skipRules = false;
 };
 
 #endif // LYRICSPROVIDER_H
