@@ -22,25 +22,30 @@
         <translation>Liedtekst Module</translation>
     </message>
     <message>
-        <location filename="../lyricsfactory.cpp" line="50"/>
+        <location filename="../lyricsfactory.cpp" line="49"/>
         <source>About Lyrics Plugin</source>
         <translation>Over de Liedtekst Module</translation>
     </message>
     <message>
-        <location filename="../lyricsfactory.cpp" line="51"/>
+        <location filename="../lyricsfactory.cpp" line="50"/>
         <source>Qmmp Lyrics Plugin</source>
         <translation>Liedtekst Module voor Qmmp</translation>
     </message>
     <message>
-        <location filename="../lyricsfactory.cpp" line="52"/>
+        <location filename="../lyricsfactory.cpp" line="51"/>
         <source>This plugin retrieves lyrics from LyricWiki</source>
         <translation>Deze module haalt liedteksten van LyricWiki</translation>
     </message>
     <message>
-        <location filename="../lyricsfactory.cpp" line="53"/>
+        <location filename="../lyricsfactory.cpp" line="52"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
+    <message>
+        <location filename="../lyricsfactory.cpp" line="53"/>
+        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
+        <translation>Gebaseerd op het Ultimate Lyrics-script van Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</translation>
+    </message>
 </context>
 <context>
     <name>LyricsWindow</name>
@@ -50,57 +55,80 @@
         <translation>Liedtekst Module</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.ui" line="45"/>
+        <location filename="../lyricswindow.ui" line="31"/>
+        <source>Provider:</source>
+        <translation>Dienst:</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.ui" line="122"/>
+        <source>Album:</source>
+        <translation>Album:</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.ui" line="139"/>
+        <source>Track:</source>
+        <translation>Nummer:</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.ui" line="146"/>
         <source>Artist:</source>
         <translation>Artiest:</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.ui" line="55"/>
+        <location filename="../lyricswindow.ui" line="161"/>
+        <source>Year:</source>
+        <translation>Jaar:</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.ui" line="115"/>
         <source>Title:</source>
         <translation>Naam:</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.ui" line="65"/>
-        <source>Search</source>
-        <translation>Zoek</translation>
+        <location filename="../lyricswindow.cpp" line="115"/>
+        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
+        <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.ui" line="36"/>
-        <source>No connection</source>
-        <translation>Geen verbinding</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="76"/>
-        <location filename="../lyricswindow.cpp" line="207"/>
-        <source>Done</source>
-        <translation>Klaar</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="79"/>
-        <location filename="../lyricswindow.cpp" line="103"/>
-        <location filename="../lyricswindow.cpp" line="109"/>
-        <location filename="../lyricswindow.cpp" line="117"/>
-        <location filename="../lyricswindow.cpp" line="125"/>
-        <location filename="../lyricswindow.cpp" line="136"/>
-        <source>Error</source>
-        <translation>Fout</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="130"/>
-        <location filename="../lyricswindow.cpp" line="163"/>
+        <location filename="../lyricswindow.cpp" line="126"/>
         <source>Not found</source>
         <translation>Niet gevonden</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="150"/>
-        <location filename="../lyricswindow.cpp" line="176"/>
+        <location filename="../lyricswindow.cpp" line="136"/>
+        <source>Error: %1 - %2</source>
+        <translation>Fout: %1 - %2</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.cpp" line="149"/>
         <source>Receiving</source>
         <translation>Bezig met ontvangen</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="177"/>
-        <source>Lyrics: %1 - %2</source>
-        <translation>Liedtekst: %1 - %2</translation>
+        <location filename="../lyricswindow.cpp" line="204"/>
+        <source>cache</source>
+        <translation>cache</translation>
+    </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <location filename="../settingsdialog.ui" line="14"/>
+        <source>Lyrics Plugin Settings</source>
+        <translation>Songtekstinstellingen</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="29"/>
+        <source>Lyrics providers:</source>
+        <translation>Songtekstdiensten:</translation>
+    </message>
+</context>
+<context>
+    <name>UltimateLyricsParser</name>
+    <message>
+        <location filename="../ultimatelyricsparser.cpp" line="119"/>
+        <source>%1 (line: %2)</source>
+        <translation>%1 (regel: %2)</translation>
     </message>
 </context>
 </TS>
