@@ -68,6 +68,7 @@ bool UltimateLyricsParser::load(const QString &path)
                 provider->setName(attrs.value("name").toString());
                 provider->setTitle(attrs.value("title").toString());
                 provider->setUrl(attrs.value("url").toString());
+                provider->setCharset(attrs.value("charser").toString());
                 m_providers << provider;
             }
             else if(reader.name() == "urlFormat" && !m_providers.isEmpty())
@@ -134,20 +135,21 @@ const QList<LyricsProvider *> &UltimateLyricsParser::providers()
 
 LyricsProvider *UltimateLyricsParser::provider(const QString &name) const
 {
-    foreach(LyricsProvider *provider, m_providers)
+    for(LyricsProvider *provider : qAsConst(m_providers))
     {
         if(provider->name() == name)
             return provider;
     }
-    return 0;
+    return nullptr;
 }
 
 QStringList UltimateLyricsParser::defaultProviders()
 {
-    QStringList out;
-    out << "Encyclopaedia Metallum"
-        << "letras.mus.br"
-        << "darklyrics.com";
+    QStringList out = {
+        "Encyclopaedia Metallum",
+        "letras.mus.br",
+        "darklyrics.com"
+    };
 
     return out;
 }
