@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,8 @@
  ***************************************************************************/
 
 #include <QtDBus>
-#include "mpris2/root2object.h"
-#include "mpris2/player2object.h"
+#include "root2object.h"
+#include "player2object.h"
 #include "mpris.h"
 
 MPRIS::MPRIS(QObject *parent) : QObject(parent)
