@@ -36,7 +36,7 @@ class PopupWidget : public QFrame
 {
     Q_OBJECT
 public:
-    PopupWidget(QWidget *parent = 0);
+    PopupWidget(QWidget *parent = nullptr);
 
     ~PopupWidget();
 
@@ -57,7 +57,7 @@ public:
     void showVolume(int);
 
 protected:
-    virtual void mousePressEvent (QMouseEvent *);
+    virtual void mousePressEvent (QMouseEvent *) override;
 
 private:
     void updatePosition();
