@@ -32,13 +32,13 @@ class SettingsDialog : public QDialog
 {
 Q_OBJECT
 public:
-    SettingsDialog(QWidget *parent = 0);
+    SettingsDialog(QWidget *parent = nullptr);
 
     virtual ~SettingsDialog();
 
 
 public slots:
-    virtual void accept();
+    virtual void accept() override;
 
 private slots:
     void on_fontButton_pressed();
