@@ -1,25 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fi">
+<TS version="2.1" language="fi">
 <context>
     <name>NotifierFactory</name>
     <message>
-        <location filename="../notifierfactory.cpp" line="30"/>
+        <location filename="../notifierfactory.cpp" line="29"/>
         <source>Notifier Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="50"/>
+        <location filename="../notifierfactory.cpp" line="49"/>
         <source>About Notifier Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="51"/>
+        <location filename="../notifierfactory.cpp" line="50"/>
         <source>Qmmp Notifier Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../notifierfactory.cpp" line="52"/>
+        <location filename="../notifierfactory.cpp" line="51"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -29,7 +29,7 @@
     <message>
         <location filename="../popupwidget.cpp" line="116"/>
         <source>Volume:</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänenvoimakkuus:</translation>
     </message>
 </context>
 <context>
@@ -83,7 +83,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="325"/>
         <source>Volume change notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänenvoimakkuuden muutoksen ilmoitus</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="332"/>
@@ -93,7 +93,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="361"/>
         <source>Playback resume notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Toiston jatkamisen ilmoitus</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="368"/>
@@ -103,7 +103,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="375"/>
         <source>Disable notifications when another application is in the Full Screen Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Poista ilmoitukset käytöstä, kun jokin toinen sovellus on koko näytön tilassa</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="378"/>
