@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,6 +36,7 @@
 #include <taglib/id3v2tag.h>
 #include <taglib/textidentificationframe.h>
 #include <taglib/mp4file.h>
+#include <taglib/opusfile.h>
 #include "rgscanner.h"
 #include "gain_analysis.h"
 #include "rgscandialog.h"
@@ -57,7 +58,7 @@ RGScanDialog::RGScanDialog(QList <PlayListTrack *> tracks,  QWidget *parent) : Q
 
     QStringList paths;
     MetaDataFormatter formatter("%if(%p&%t,%p - %t,%f) - %l");
-    foreach(PlayListTrack *track, tracks)
+    for(const PlayListTrack *track : qAsConst(tracks))
     {
         //skip streams
         if(track->duration() == 0 || track->path().contains("://"))
@@ -76,7 +77,8 @@ RGScanDialog::RGScanDialog(QList <PlayListTrack *> tracks,  QWidget *parent) : Q
                 ext == "oga" || //ogg flac
                 ext == "ogg" ||  //ogg vorbis
                 ext == "wv" || //wavpack
-                ext == "m4a") //aac (mp4 container)
+                ext == "m4a" || //aac (mp4 container)
+                ext == "opus")
         {
             paths.append(track->path());
             QString name = formatter.format(track);
@@ -161,7 +163,7 @@ void RGScanDialog::onScanFinished(QString url)
 
     bool stopped = true;
 
-    foreach (RGScanner *scanner, m_scanners)
+    for(const RGScanner *scanner : qAsConst(m_scanners))
     {
         if(scanner->isRunning() || scanner->isPending())
             stopped = false;
@@ -175,7 +177,7 @@ void RGScanDialog::onScanFinished(QString url)
         QMultiMap<QString, ReplayGainInfoItem*> itemGroupMap; //items grouped  by album
 
         //group by album name
-        foreach (RGScanner *scanner, m_scanners)
+        for(RGScanner *scanner : qAsConst(m_scanners))
         {
             if(!scanner->hasValues())
                 continue;
@@ -188,7 +190,7 @@ void RGScanDialog::onScanFinished(QString url)
             itemGroupMap.insert(album, item);
         }
         //calculate album peak and gain
-        foreach (QString album, itemGroupMap.keys())
+        for(const QString &album : itemGroupMap.keys())
         {
             QList<ReplayGainInfoItem*> items = itemGroupMap.values(album);
             GainHandle_t **a = (GainHandle_t **) malloc(items.count()*sizeof(GainHandle_t *));
@@ -200,7 +202,7 @@ void RGScanDialog::onScanFinished(QString url)
             }
             double album_gain = GetAlbumGain(a, items.count());
             free(a);
-            foreach (ReplayGainInfoItem *item, items)
+            for(ReplayGainInfoItem *item : qAsConst(items))
             {
                 item->info[Qmmp::REPLAYGAIN_ALBUM_PEAK] = album_peak;
                 item->info[Qmmp::REPLAYGAIN_ALBUM_GAIN] = album_gain;
@@ -218,7 +220,7 @@ void RGScanDialog::onScanFinished(QString url)
         {
             QString url = m_ui.tableWidget->item(i, 0)->data(Qt::UserRole).toString();
             bool found = false;
-            foreach (ReplayGainInfoItem *item, m_replayGainItemList)
+            for(const ReplayGainInfoItem *item : qAsConst(m_replayGainItemList))
             {
                 if(item->url == url)
                 {
@@ -254,7 +256,7 @@ void RGScanDialog::stop()
 {
     if(m_scanners.isEmpty())
         return;
-    foreach (RGScanner *scaner, m_scanners)
+    for(RGScanner *scaner : qAsConst(m_scanners))
     {
         scaner->stop();
     }
@@ -265,7 +267,7 @@ void RGScanDialog::stop()
 
 RGScanner *RGScanDialog::findScannerByUrl(const QString &url)
 {
-    foreach (RGScanner *scanner, m_scanners)
+    for(RGScanner *scanner : qAsConst(m_scanners))
     {
         if(scanner->url() == url)
             return scanner;
@@ -393,7 +395,7 @@ void RGScanDialog::on_writeButton_clicked()
 
     qDebug("RGScanDialog: writing ReplayGain values...");
 
-    foreach (ReplayGainInfoItem *item, m_replayGainItemList)
+    for(ReplayGainInfoItem *item : qAsConst(m_replayGainItemList))
     {
         QString ext = item->url.section(".", -1).toLower();
 
@@ -402,7 +404,11 @@ void RGScanDialog::on_writeButton_clicked()
             TagLib::MPEG::File file(qPrintable(item->url));
             writeAPETag(file.APETag(true), item);
             writeID3v2Tag(file.ID3v2Tag(true), item);
+#if ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION <= 11))
             file.save(TagLib::MPEG::File::APE | TagLib::MPEG::File::ID3v2, false);
+#else
+            file.save(TagLib::MPEG::File::APE | TagLib::MPEG::File::ID3v2, TagLib::File::StripNone);
+#endif
         }
         else if(ext == "flac") //flac
         {
@@ -434,5 +440,11 @@ void RGScanDialog::on_writeButton_clicked()
             writeMP4Tag(file.tag(), item);
             file.save();
         }
+        else if(ext == "opus")
+        {
+            TagLib::Ogg::Opus::File file(qPrintable(item->url));
+            writeVorbisComment(file.tag(), item);
+            file.save();
+        }
     }
 }
