@@ -21,7 +21,6 @@
 #define RGSCANFACTORY_H
 
 #include <QObject>
-#include <QTranslator>
 #include <QDialog>
 #include <qmmpui/general.h>
 #include <qmmpui/generalfactory.h>
@@ -35,11 +34,11 @@ Q_OBJECT
 Q_PLUGIN_METADATA(IID "org.qmmp.qmmpui.GeneralFactoryInterface.1.0")
 Q_INTERFACES(GeneralFactory)
 public:
-    const GeneralProperties properties() const;
-    QObject *create(QObject *parent);
-    QDialog *createConfigDialog(QWidget *parent);
-    void showAbout(QWidget *parent);
-    QTranslator *createTranslator(QObject *parent);
+    GeneralProperties properties() const override;
+    QObject *create(QObject *parent) override;
+    QDialog *createConfigDialog(QWidget *parent) override;
+    void showAbout(QWidget *parent) override;
+    QString translation() const override;
 };
 
 #endif
