@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,10 +29,9 @@
 #include <QUrlQuery>
 #include <QElapsedTimer>
 #include <QTimer>
-#include <QDateTime>
-#include <QDir>
 #include <QDesktopServices>
 #include <QSettings>
+#include <QDateTime>
 #include <qmmp/soundcore.h>
 #include <qmmp/qmmpsettings.h>
 #include <qmmp/qmmp.h>
@@ -82,15 +81,10 @@ void ScrobblerResponse::parse(QIODevice *device)
 Scrobbler::Scrobbler(const QString &scrobblerUrl, const QString &name, QObject *parent)
     : QObject(parent)
 {
-    m_notificationReply = nullptr;
-    m_submitedSongs = 0;
-    m_submitReply = nullptr;
-    m_previousState = Qmmp::Stopped;
-    m_elapsed = 0;
     m_scrobblerUrl = scrobblerUrl;
     m_name = name;
     m_time = new QElapsedTimer();
-    m_cache = new ScrobblerCache(Qmmp::configDir() +"/scrobbler_"+name+".cache");
+    m_cache = new ListenCache(Qmmp::configDir() +"/scrobbler_"+name+".cache");
     m_ua = QString("qmmp-plugins/%1").arg(Qmmp::strVersion().toLower()).toLatin1();
     m_http = new QNetworkAccessManager(this);
     m_core = SoundCore::instance();
@@ -128,22 +122,21 @@ void Scrobbler::setState(Qmmp::State state)
 {
     if(state == Qmmp::Playing && m_previousState == Qmmp::Paused)
     {
-        qDebug("Scrobbler[%s]: resuming from %d seconds played", qPrintable(m_name), m_elapsed / 1000);
+        qDebug("Scrobbler[%s]: resuming from %d seconds played", qPrintable(m_name), int(m_elapsed / 1000));
         m_time->restart();
     }
     else if(state == Qmmp::Paused)
     {
         m_elapsed += m_time->elapsed();
-        qDebug("Scrobbler[%s]: pausing after %d seconds played", qPrintable(m_name), m_elapsed / 1000);
+        qDebug("Scrobbler[%s]: pausing after %d seconds played", qPrintable(m_name), int(m_elapsed / 1000));
     }
     else if(state == Qmmp::Stopped && !m_song.metaData().isEmpty())
     {
         if(m_previousState == Qmmp::Playing)
             m_elapsed += m_time->elapsed();
 
-        m_elapsed /= 1000; //convert to seconds
-        if((m_elapsed > 240) || (m_elapsed > MIN_SONG_LENGTH && m_song.length() == 0) ||
-                (m_elapsed > int(m_song.length()/2) && m_song.length() > MIN_SONG_LENGTH))
+        if((m_elapsed > 240000) || (m_elapsed > MIN_SONG_LENGTH && m_song.duration() == 0) ||
+                (m_elapsed > int(m_song.duration() / 2) && m_song.duration() > MIN_SONG_LENGTH))
         {
             m_cachedSongs << m_song;
             m_cache->save(m_cachedSongs);
@@ -158,15 +151,15 @@ void Scrobbler::setState(Qmmp::State state)
 
 void Scrobbler::updateMetaData()
 {
-    QMap <Qmmp::MetaData, QString> metadata = m_core->metaData();
+    TrackInfo info = m_core->trackInfo();
     if(m_core->state() != Qmmp::Playing)
         return;
 
-    if(!m_song.metaData().isEmpty() && m_song.metaData() != metadata)
+    if(!m_song.metaData().isEmpty() && m_song.metaData() != info.metaData())
     {
-        int elapsed = (m_elapsed + m_time->elapsed()) / 1000;
-        if((elapsed > 240) || (elapsed > MIN_SONG_LENGTH && m_song.length() == 0) ||
-                (elapsed > int(m_song.length()/2) && m_song.length() > MIN_SONG_LENGTH))
+        int elapsed = (m_elapsed + m_time->elapsed());
+        if((elapsed > 240000) || (elapsed > MIN_SONG_LENGTH && m_song.duration() == 0) ||
+                (elapsed > int(m_song.duration() / 2) && m_song.duration() > MIN_SONG_LENGTH))
         {
             m_cachedSongs << m_song;
             m_cache->save(m_cachedSongs);
@@ -176,9 +169,9 @@ void Scrobbler::updateMetaData()
         m_song.clear();
     }
 
-    if(!metadata.value(Qmmp::TITLE).isEmpty() && !metadata.value(Qmmp::ARTIST).isEmpty())
+    if(!info.value(Qmmp::TITLE).isEmpty() && !info.value(Qmmp::ARTIST).isEmpty())
     {
-        m_song = SongInfo(metadata, m_core->duration()/1000);
+        m_song = SongInfo(info);
         m_song.setTimeStamp(QDateTime::currentDateTime().toTime_t());
         sendNotification(m_song);
     }
@@ -256,7 +249,7 @@ void Scrobbler::processResponse(QNetworkReply *reply)
         else if(error_code == "9") //invalid session key
         {
             m_session.clear();
-            qWarning("Scrobbler[%s]: invalid session key, scrobbling disabled", qPrintable(m_name));
+            qWarning("Scrobbler[%s]: invalid session key, scrobbling has been disabled", qPrintable(m_name));
         }
     }
     reply->deleteLater();
@@ -268,6 +261,8 @@ void Scrobbler::setupProxy()
     if (gs->isProxyEnabled())
     {
         QNetworkProxy proxy(QNetworkProxy::HttpProxy, gs->proxy().host(),  gs->proxy().port());
+        if(gs->proxyType() == QmmpSettings::SOCKS5_PROXY)
+            proxy.setType(QNetworkProxy::Socks5Proxy);
         if(gs->useProxyAuth())
         {
             proxy.setUser(gs->proxy().userName());
@@ -291,20 +286,20 @@ void Scrobbler::submit()
     for (int i = 0; i < m_submitedSongs; ++i)
     {
         SongInfo info = m_cachedSongs[i];
-        params.insert(QString("track[%1]").arg(i),info.metaData(Qmmp::TITLE));
+        params.insert(QString("track[%1]").arg(i),info.value(Qmmp::TITLE));
         params.insert(QString("timestamp[%1]").arg(i),QString("%1").arg(info.timeStamp()));
-        params.insert(QString("artist[%1]").arg(i),info.metaData(Qmmp::ARTIST));
-        params.insert(QString("album[%1]").arg(i),info.metaData(Qmmp::ALBUM));
-        params.insert(QString("trackNumber[%1]").arg(i),info.metaData(Qmmp::TRACK));
-        if(info.length() > 0)
-            params.insert(QString("duration[%1]").arg(i),QString("%1").arg(info.length()));
+        params.insert(QString("artist[%1]").arg(i),info.value(Qmmp::ARTIST));
+        params.insert(QString("album[%1]").arg(i),info.value(Qmmp::ALBUM));
+        params.insert(QString("trackNumber[%1]").arg(i),info.value(Qmmp::TRACK));
+        if(info.duration() > 0)
+            params.insert(QString("duration[%1]").arg(i),QString("%1").arg(info.duration() / 1000));
     }
     params.insert("api_key", API_KEY);
     params.insert("method", "track.scrobble");
     params.insert("sk", m_session);
 
-    QStringList keys = params.keys();
-    foreach (QString key, keys) //removes empty keys
+    const QStringList keys = params.keys();
+    for(const QString &key : qAsConst(keys)) //removes empty keys
     {
         if(params.value(key).isEmpty() || params.value(key) == "0")
             params.remove(key);
@@ -315,7 +310,7 @@ void Scrobbler::submit()
 
     QUrlQuery body("");
     QByteArray data;
-    foreach (QString key, params.keys())
+    for(const QString &key : params.keys())
     {
         body.addQueryItem(key, params.value(key));
         data.append(key.toUtf8() + params.value(key).toUtf8());
@@ -341,19 +336,20 @@ void Scrobbler::sendNotification(const SongInfo &info)
     qDebug("Scrobbler[%s]: sending notification", qPrintable(m_name));
 
     QMap <QString, QString> params;
-    params.insert("track", info.metaData(Qmmp::TITLE));
-    params.insert("artist", info.metaData(Qmmp::ARTIST));
-    if(!info.metaData(Qmmp::ALBUM).isEmpty())
-        params.insert("album", info.metaData(Qmmp::ALBUM));
-    if(!info.metaData(Qmmp::TRACK).isEmpty())
-        params.insert("trackNumber", info.metaData(Qmmp::TRACK));
-    if(info.length() > 0)
-        params.insert("duration", QString("%1").arg(info.length()));
+    params.insert("track", info.value(Qmmp::TITLE));
+    params.insert("artist", info.value(Qmmp::ARTIST));
+    if(!info.value(Qmmp::ALBUM).isEmpty())
+        params.insert("album", info.value(Qmmp::ALBUM));
+    if(!info.value(Qmmp::TRACK).isEmpty())
+        params.insert("trackNumber", info.value(Qmmp::TRACK));
+    if(info.duration() > 0)
+        params.insert("duration", QString("%1").arg(info.duration() / 1000));
     params.insert("api_key", API_KEY);
     params.insert("method", "track.updateNowPlaying");
     params.insert("sk", m_session);
 
-    foreach (QString key, params) //removes empty keys
+    const QStringList keys = params.keys();
+    for(const QString &key : qAsConst(keys)) //removes empty keys
     {
         if(params.value(key).isEmpty())
             params.remove(key);
@@ -364,7 +360,7 @@ void Scrobbler::sendNotification(const SongInfo &info)
 
     QUrlQuery body("");
     QByteArray data;
-    foreach (QString key, params.keys())
+    for(const QString &key : params.keys())
     {
         body.addQueryItem(key, params.value(key));
         data.append(key.toUtf8() + params.value(key).toUtf8());
@@ -399,6 +395,8 @@ ScrobblerAuth::ScrobblerAuth(const QString &scrobblerUrl, const QString &authUrl
     if (gs->isProxyEnabled())
     {
         QNetworkProxy proxy(QNetworkProxy::HttpProxy, gs->proxy().host(),  gs->proxy().port());
+        if(gs->proxyType() == QmmpSettings::SOCKS5_PROXY)
+            proxy.setType(QNetworkProxy::Socks5Proxy);
         if(gs->useProxyAuth())
         {
             proxy.setUser(gs->proxy().userName());
@@ -473,7 +471,7 @@ void ScrobblerAuth::checkSession(const QString &session)
 
     QUrlQuery body("");
     QByteArray data;
-    foreach (QString key, params.keys())
+    for(const QString &key : params.keys())
     {
         body.addQueryItem(key, params.value(key));
         data.append(key.toUtf8() + params.value(key).toUtf8());
