@@ -39,23 +39,20 @@
     <message>
         <location filename="../settingsdialog.ui" line="31"/>
         <location filename="../settingsdialog.ui" line="104"/>
-        <location filename="../settingsdialog.ui" line="160"/>
         <source>Session:</source>
-        <translation type="unfinished"></translation>
+        <translation>Oturum:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
         <location filename="../settingsdialog.ui" line="117"/>
-        <location filename="../settingsdialog.ui" line="173"/>
         <source>Check</source>
-        <translation type="unfinished"></translation>
+        <translation>Denetle</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="63"/>
         <location filename="../settingsdialog.ui" line="95"/>
-        <location filename="../settingsdialog.ui" line="151"/>
         <source>Register new session</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni oturumu kaydettir.</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="73"/>
@@ -63,69 +60,64 @@
         <translation>Libre.fm</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="129"/>
-        <source>ListenBrainz</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="126"/>
-        <location filename="../settingsdialog.cpp" line="152"/>
-        <location filename="../settingsdialog.cpp" line="217"/>
+        <location filename="../settingsdialog.cpp" line="106"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
+        <location filename="../settingsdialog.cpp" line="183"/>
         <source>Message</source>
-        <translation type="unfinished"></translation>
+        <translation>İleti</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="127"/>
+        <location filename="../settingsdialog.cpp" line="107"/>
         <source>1. Wait for browser startup</source>
-        <translation type="unfinished"></translation>
+        <translation>1. Tarayıcı başlangıcını bekleyin</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="128"/>
+        <location filename="../settingsdialog.cpp" line="108"/>
         <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="129"/>
+        <location filename="../settingsdialog.cpp" line="109"/>
         <source>3. Press &quot;OK&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>3.  &quot;OK&quot; &apos;a basın</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="134"/>
-        <location filename="../settingsdialog.cpp" line="138"/>
-        <location filename="../settingsdialog.cpp" line="172"/>
-        <location filename="../settingsdialog.cpp" line="176"/>
-        <location filename="../settingsdialog.cpp" line="227"/>
-        <location filename="../settingsdialog.cpp" line="231"/>
+        <location filename="../settingsdialog.cpp" line="114"/>
+        <location filename="../settingsdialog.cpp" line="118"/>
+        <location filename="../settingsdialog.cpp" line="147"/>
+        <location filename="../settingsdialog.cpp" line="151"/>
+        <location filename="../settingsdialog.cpp" line="191"/>
+        <location filename="../settingsdialog.cpp" line="195"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="134"/>
-        <location filename="../settingsdialog.cpp" line="172"/>
-        <location filename="../settingsdialog.cpp" line="227"/>
+        <location filename="../settingsdialog.cpp" line="114"/>
+        <location filename="../settingsdialog.cpp" line="147"/>
+        <location filename="../settingsdialog.cpp" line="191"/>
         <source>Network error</source>
-        <translation type="unfinished"></translation>
+        <translation>Ağ hatası</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="138"/>
-        <location filename="../settingsdialog.cpp" line="176"/>
+        <location filename="../settingsdialog.cpp" line="118"/>
+        <location filename="../settingsdialog.cpp" line="151"/>
         <source>Unable to register new session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="152"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
         <source>New session has been received successfully</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni oturum başarıyla alındı</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="217"/>
+        <location filename="../settingsdialog.cpp" line="183"/>
         <source>Permission granted</source>
-        <translation type="unfinished"></translation>
+        <translation>Yetki verildi</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="231"/>
+        <location filename="../settingsdialog.cpp" line="195"/>
         <source>Permission denied</source>
-        <translation type="unfinished"></translation>
+        <translation>Yetkilendirme reddedildi</translation>
     </message>
 </context>
 </TS>
