@@ -39,21 +39,18 @@
     <message>
         <location filename="../settingsdialog.ui" line="31"/>
         <location filename="../settingsdialog.ui" line="104"/>
-        <location filename="../settingsdialog.ui" line="160"/>
         <source>Session:</source>
         <translation>会议：</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
         <location filename="../settingsdialog.ui" line="117"/>
-        <location filename="../settingsdialog.ui" line="173"/>
         <source>Check</source>
         <translation>检查</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="63"/>
         <location filename="../settingsdialog.ui" line="95"/>
-        <location filename="../settingsdialog.ui" line="151"/>
         <source>Register new session</source>
         <translation>注册新会议</translation>
     </message>
@@ -63,67 +60,62 @@
         <translation>Libre.fm</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="129"/>
-        <source>ListenBrainz</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="126"/>
-        <location filename="../settingsdialog.cpp" line="152"/>
-        <location filename="../settingsdialog.cpp" line="217"/>
+        <location filename="../settingsdialog.cpp" line="106"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
+        <location filename="../settingsdialog.cpp" line="183"/>
         <source>Message</source>
         <translation>信息</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="127"/>
+        <location filename="../settingsdialog.cpp" line="107"/>
         <source>1. Wait for browser startup</source>
         <translation>1.等候浏览器启动</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="128"/>
+        <location filename="../settingsdialog.cpp" line="108"/>
         <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
         <translation>2.允许Qmmp向您的%1账户推荐类似曲目</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="129"/>
+        <location filename="../settingsdialog.cpp" line="109"/>
         <source>3. Press &quot;OK&quot;</source>
         <translation>3.按“OK”</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="134"/>
-        <location filename="../settingsdialog.cpp" line="138"/>
-        <location filename="../settingsdialog.cpp" line="172"/>
-        <location filename="../settingsdialog.cpp" line="176"/>
-        <location filename="../settingsdialog.cpp" line="227"/>
-        <location filename="../settingsdialog.cpp" line="231"/>
+        <location filename="../settingsdialog.cpp" line="114"/>
+        <location filename="../settingsdialog.cpp" line="118"/>
+        <location filename="../settingsdialog.cpp" line="147"/>
+        <location filename="../settingsdialog.cpp" line="151"/>
+        <location filename="../settingsdialog.cpp" line="191"/>
+        <location filename="../settingsdialog.cpp" line="195"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="134"/>
-        <location filename="../settingsdialog.cpp" line="172"/>
-        <location filename="../settingsdialog.cpp" line="227"/>
+        <location filename="../settingsdialog.cpp" line="114"/>
+        <location filename="../settingsdialog.cpp" line="147"/>
+        <location filename="../settingsdialog.cpp" line="191"/>
         <source>Network error</source>
         <translation>网络错误</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="138"/>
-        <location filename="../settingsdialog.cpp" line="176"/>
+        <location filename="../settingsdialog.cpp" line="118"/>
+        <location filename="../settingsdialog.cpp" line="151"/>
         <source>Unable to register new session</source>
         <translation>无法注册新会话</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="152"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
         <source>New session has been received successfully</source>
         <translation>新会话已被成功接收</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="217"/>
+        <location filename="../settingsdialog.cpp" line="183"/>
         <source>Permission granted</source>
         <translation>权限已授予</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="231"/>
+        <location filename="../settingsdialog.cpp" line="195"/>
         <source>Permission denied</source>
         <translation>权限被拒绝</translation>
     </message>
