@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<TS version="2.1" language="pl_PL">
 <context>
     <name>SettingsDialog</name>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>Status Icon Plugin Settings</source>
-        <translation>Ustawienia wtyczki Ikona Statusu</translation>
+        <translation>Ustawienia wtyczki Ikona statusu</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
@@ -27,7 +27,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="91"/>
         <source>Try to split file name when no tag</source>
-        <translation>Próbuj rozdzielić nazwę pliku jeśli brakuje tagu</translation>
+        <translation>Próbuj rozdzielić nazwę pliku, jeśli brakuje tagu</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="98"/>
@@ -52,7 +52,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="214"/>
         <source>32</source>
-        <translation type="unfinished">32</translation>
+        <translation>32</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="225"/>
@@ -73,42 +73,42 @@
 <context>
     <name>StatusIcon</name>
     <message>
-        <location filename="../statusicon.cpp" line="70"/>
+        <location filename="../statusicon.cpp" line="71"/>
         <source>Play</source>
         <translation>Odtwarzaj</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="71"/>
+        <location filename="../statusicon.cpp" line="72"/>
         <source>Pause</source>
         <translation>Pauza</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="72"/>
+        <location filename="../statusicon.cpp" line="73"/>
         <source>Stop</source>
         <translation>Zatrzymaj</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="74"/>
+        <location filename="../statusicon.cpp" line="75"/>
         <source>Next</source>
         <translation>Następny</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="75"/>
+        <location filename="../statusicon.cpp" line="76"/>
         <source>Previous</source>
         <translation>Poprzedni</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="77"/>
+        <location filename="../statusicon.cpp" line="78"/>
         <source>Exit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="119"/>
+        <location filename="../statusicon.cpp" line="120"/>
         <source>Stopped</source>
         <translation>Zatrzymane</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="144"/>
+        <location filename="../statusicon.cpp" line="145"/>
         <source>Now Playing</source>
         <translation>Teraz odtwarza</translation>
     </message>
@@ -116,34 +116,34 @@
 <context>
     <name>StatusIconFactory</name>
     <message>
-        <location filename="../statusiconfactory.cpp" line="30"/>
+        <location filename="../statusiconfactory.cpp" line="29"/>
         <source>Status Icon Plugin</source>
-        <translation>Wtyczka Ikona Statusu</translation>
+        <translation>Wtyczka Ikona statusu</translation>
+    </message>
+    <message>
+        <location filename="../statusiconfactory.cpp" line="49"/>
+        <source>About Status Icon Plugin</source>
+        <translation>O wtyczce Ikona statusu</translation>
     </message>
     <message>
         <location filename="../statusiconfactory.cpp" line="50"/>
-        <source>About Status Icon Plugin</source>
-        <translation>O Wtyczce Ikona Statusu</translation>
+        <source>Qmmp Status Icon Plugin</source>
+        <translation>Wtyczka Ikona statusu dla Qmmp</translation>
     </message>
     <message>
         <location filename="../statusiconfactory.cpp" line="51"/>
-        <source>Qmmp Status Icon Plugin</source>
-        <translation>Wtyczka Ikona Statusu dla Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../statusiconfactory.cpp" line="52"/>
         <source>Written by:</source>
         <translation>Napisana przez:</translation>
     </message>
     <message>
-        <location filename="../statusiconfactory.cpp" line="53"/>
+        <location filename="../statusiconfactory.cpp" line="52"/>
         <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../statusiconfactory.cpp" line="54"/>
+        <location filename="../statusiconfactory.cpp" line="53"/>
         <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
     </message>
 </context>
 </TS>
