@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -96,6 +96,8 @@ StreamWindow::StreamWindow(QWidget *parent)
     if (gs->isProxyEnabled())
     {
         QNetworkProxy proxy(QNetworkProxy::HttpProxy, gs->proxy().host(),  gs->proxy().port());
+        if(gs->proxyType() == QmmpSettings::SOCKS5_PROXY)
+            proxy.setType(QNetworkProxy::Socks5Proxy);
         if(gs->useProxyAuth())
         {
             proxy.setUser(gs->proxy().userName());
@@ -179,27 +181,33 @@ void StreamWindow::on_updatePushButton_clicked()
 
 void StreamWindow::on_addPushButton_clicked()
 {
-    QStringList urls;
+    QList<PlayListTrack *> tracks;
     if(m_ui->tabWidget->currentIndex() == 0)
     {
-        QModelIndexList indexes = m_ui->favoritesTableView->selectionModel()->selectedRows(0);
-        foreach(QModelIndex index, indexes)
+        const QModelIndexList indexes = m_ui->favoritesTableView->selectionModel()->selectedRows(0);
+        for(const QModelIndex &index : qAsConst(indexes))
         {
             QModelIndex source_index = m_favoritesFilterModel->mapToSource(index);
-            urls.append(m_favoritesModel->item(source_index.row(),0)->data().toString());
+            tracks << new PlayListTrack();
+            tracks.last()->setPath(m_favoritesModel->item(source_index.row(),0)->data().toString());
+            tracks.last()->setValue(Qmmp::TITLE, m_favoritesModel->item(source_index.row(),0)->text());
+            tracks.last()->setValue(Qmmp::GENRE, m_favoritesModel->item(source_index.row(),1)->text());
+
         }
     }
     else
     {
-        QModelIndexList indexes = m_ui->icecastTableView->selectionModel()->selectedRows(0);
-        foreach(QModelIndex index, indexes)
+        const QModelIndexList indexes = m_ui->icecastTableView->selectionModel()->selectedRows(0);
+        for(const QModelIndex &index : qAsConst(indexes))
         {
             QModelIndex source_index = m_iceCastFilterModel->mapToSource(index);
-            urls.append(m_iceCastModel->item(source_index.row(),0)->data().toString());
+            tracks << new PlayListTrack();
+            tracks.last()->setPath(m_iceCastModel->item(source_index.row(),0)->data().toString());
+            tracks.last()->setValue(Qmmp::TITLE, m_iceCastModel->item(source_index.row(),0)->text());
+            tracks.last()->setValue(Qmmp::GENRE, m_iceCastModel->item(source_index.row(),1)->text());
         }
     }
-    urls.removeDuplicates();
-    PlayListManager::instance()->add(urls);
+    PlayListManager::instance()->add(tracks);
 }
 
 void StreamWindow::on_filterLineEdit_textChanged(const QString &text)
@@ -226,8 +234,8 @@ void StreamWindow::execFavoritesMenu(const QPoint &pos)
 
 void StreamWindow::addToFavorites()
 {
-    QModelIndexList indexes = m_ui->icecastTableView->selectionModel()->selectedRows(0);
-    foreach(QModelIndex index, indexes)
+    const QModelIndexList indexes = m_ui->icecastTableView->selectionModel()->selectedRows(0);
+    for(const QModelIndex &index : qAsConst(indexes))
     {
         QModelIndex source_index = m_iceCastFilterModel->mapToSource(index);
         int row = source_index.row();
@@ -299,9 +307,9 @@ void StreamWindow::removeFromFavorites()
 {
     if(m_ui->tabWidget->currentIndex() != 0)
         return;
-    QModelIndexList indexes = m_ui->favoritesTableView->selectionModel()->selectedRows(0);
+    const QModelIndexList indexes = m_ui->favoritesTableView->selectionModel()->selectedRows(0);
     QList<int> rows_to_remove;
-    foreach(QModelIndex index, indexes)
+    for(const QModelIndex &index : qAsConst(indexes))
     {
         rows_to_remove.append(m_favoritesFilterModel->mapToSource(index).row());
     }
