@@ -6,12 +6,12 @@
     <message>
         <location filename="../editstreamdialog.ui" line="14"/>
         <source>Edit Stream</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokkaa suoratoistoa</translation>
     </message>
     <message>
         <location filename="../editstreamdialog.ui" line="34"/>
         <source>URL:</source>
-        <translation type="unfinished"></translation>
+        <translation>Osoite:</translation>
     </message>
     <message>
         <location filename="../editstreamdialog.ui" line="44"/>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../editstreamdialog.ui" line="64"/>
         <source>Bitrate:</source>
-        <translation type="unfinished"></translation>
+        <translation>Bittinopeus:</translation>
     </message>
     <message>
         <location filename="../editstreamdialog.ui" line="74"/>
@@ -39,7 +39,7 @@
     <message>
         <location filename="../streambrowser.cpp" line="33"/>
         <source>Add Stream</source>
-        <translation type="unfinished"></translation>
+        <translation>Lisää suoratoisto</translation>
     </message>
     <message>
         <location filename="../streambrowser.cpp" line="35"/>
@@ -80,7 +80,7 @@
     <message>
         <location filename="../streamwindow.ui" line="14"/>
         <source>Stream Browser</source>
-        <translation type="unfinished"></translation>
+        <translation>Suoratoistoselain</translation>
     </message>
     <message>
         <location filename="../streamwindow.ui" line="31"/>
@@ -129,53 +129,53 @@
         <location filename="../streamwindow.cpp" line="59"/>
         <location filename="../streamwindow.cpp" line="77"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Muoto</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="132"/>
+        <location filename="../streamwindow.cpp" line="134"/>
         <source>&amp;Add to favorites</source>
         <translation>&amp;Lisää suosikkeihin</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="135"/>
+        <location filename="../streamwindow.cpp" line="137"/>
         <source>&amp;Add to playlist</source>
         <translation>&amp;Lisää soittolistaan</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="138"/>
+        <location filename="../streamwindow.cpp" line="140"/>
         <source>&amp;Create</source>
         <translation>&amp;Luo</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="140"/>
+        <location filename="../streamwindow.cpp" line="142"/>
         <source>&amp;Edit</source>
         <translation>&amp;Muokkaa</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="143"/>
+        <location filename="../streamwindow.cpp" line="145"/>
         <source>&amp;Remove</source>
         <translation>Poi&amp;sta</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="153"/>
+        <location filename="../streamwindow.cpp" line="155"/>
         <source>Done</source>
         <translation>Valmis</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="156"/>
-        <location filename="../streamwindow.cpp" line="157"/>
+        <location filename="../streamwindow.cpp" line="158"/>
+        <location filename="../streamwindow.cpp" line="159"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="176"/>
+        <location filename="../streamwindow.cpp" line="178"/>
         <source>Receiving</source>
         <translation>Vastaanotetaan</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="273"/>
+        <location filename="../streamwindow.cpp" line="281"/>
         <source>Edit Stream</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokkaa suoratoistoa</translation>
     </message>
 </context>
 </TS>
