@@ -132,48 +132,48 @@
         <translation>Formaat</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="132"/>
+        <location filename="../streamwindow.cpp" line="134"/>
         <source>&amp;Add to favorites</source>
         <translation>&amp;Voeg toe aan favorieten</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="135"/>
+        <location filename="../streamwindow.cpp" line="137"/>
         <source>&amp;Add to playlist</source>
         <translation>&amp;Voeg toe aan afspeellijst</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="138"/>
+        <location filename="../streamwindow.cpp" line="140"/>
         <source>&amp;Create</source>
-        <translation>&amp;Creëren</translation>
+        <translation>&amp;Maken</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="140"/>
+        <location filename="../streamwindow.cpp" line="142"/>
         <source>&amp;Edit</source>
         <translation>&amp;Bewerk</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="143"/>
+        <location filename="../streamwindow.cpp" line="145"/>
         <source>&amp;Remove</source>
         <translation>&amp;Verwijder</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="153"/>
+        <location filename="../streamwindow.cpp" line="155"/>
         <source>Done</source>
         <translation>Klaar</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="156"/>
-        <location filename="../streamwindow.cpp" line="157"/>
+        <location filename="../streamwindow.cpp" line="158"/>
+        <location filename="../streamwindow.cpp" line="159"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="176"/>
+        <location filename="../streamwindow.cpp" line="178"/>
         <source>Receiving</source>
         <translation>Bezig met ontvangen</translation>
     </message>
     <message>
-        <location filename="../streamwindow.cpp" line="273"/>
+        <location filename="../streamwindow.cpp" line="281"/>
         <source>Edit Stream</source>
         <translation>Stream bewerken</translation>
     </message>
