@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,10 +33,14 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
     addMenu(m_ui.titleChangeButton);
 
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_ui.newTrackLineEdit->setText(settings.value("TrackChange/new_track_command").toString());
-    m_ui.endOfTrackLineEdit->setText(settings.value("TrackChange/end_of_track_command").toString());
-    m_ui.endOfPlayListLineEdit->setText(settings.value("TrackChange/end_of_pl_command").toString());
-    m_ui.titleChangeLineEdit->setText(settings.value("TrackChange/title_change_command").toString());
+    settings.beginGroup("TrackChange");
+    m_ui.newTrackLineEdit->setText(settings.value("new_track_command").toString());
+    m_ui.endOfTrackLineEdit->setText(settings.value("end_of_track_command").toString());
+    m_ui.endOfPlayListLineEdit->setText(settings.value("end_of_pl_command").toString());
+    m_ui.titleChangeLineEdit->setText(settings.value("title_change_command").toString());
+    m_ui.appStartupLineEdit->setText(settings.value("application_startup_command").toString());
+    m_ui.appExitLineEdit->setText(settings.value("application_exit_command").toString());
+    settings.endGroup();
 }
 
 SettingsDialog::~SettingsDialog()
@@ -45,10 +49,14 @@ SettingsDialog::~SettingsDialog()
 void SettingsDialog::accept()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("TrackChange/new_track_command", m_ui.newTrackLineEdit->text());
-    settings.setValue("TrackChange/end_of_track_command",  m_ui.endOfTrackLineEdit->text());
-    settings.setValue("TrackChange/end_of_pl_command",  m_ui.endOfPlayListLineEdit->text());
-    settings.setValue("TrackChange/title_change_command", m_ui.titleChangeLineEdit->text());
+    settings.beginGroup("TrackChange");
+    settings.setValue("new_track_command", m_ui.newTrackLineEdit->text());
+    settings.setValue("end_of_track_command",  m_ui.endOfTrackLineEdit->text());
+    settings.setValue("end_of_pl_command",  m_ui.endOfPlayListLineEdit->text());
+    settings.setValue("title_change_command", m_ui.titleChangeLineEdit->text());
+    settings.setValue("application_startup_command", m_ui.appStartupLineEdit->text());
+    settings.setValue("application_exit_command", m_ui.appExitLineEdit->text());
+    settings.endGroup();
     QDialog::accept();
 }
 
