@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,16 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QAction>
 #include <QSettings>
 #include <QApplication>
-#include <QProgressDialog>
-#include <QMessageBox>
-#include <QFile>
-#include <QDir>
 #include <QProcess>
-#include <QMap>
-#include <QtDebug>
 #include <qmmp/soundcore.h>
 #include <qmmpui/uihelper.h>
 #include <qmmpui/playlistmodel.h>
@@ -45,10 +38,17 @@ TrackChange::TrackChange(QObject *parent) : QObject(parent)
     connect(m_core, SIGNAL(trackInfoChanged()), SLOT(onTrackInfoChanged()));
     connect(m_core, SIGNAL(finished()), SLOT(onFinised()));
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_newTrackCommand = settings.value("TrackChange/new_track_command").toString();
-    m_endOfTrackCommand = settings.value("TrackChange/end_of_track_command").toString();
-    m_endOfPlCommand = settings.value("TrackChange/end_of_pl_command").toString();
-    m_titleChangeCommand = settings.value("TrackChange/title_change_command").toString();
+    settings.beginGroup("TrackChange");
+    m_newTrackCommand = settings.value("new_track_command").toString();
+    m_endOfTrackCommand = settings.value("end_of_track_command").toString();
+    m_endOfPlCommand = settings.value("end_of_pl_command").toString();
+    m_titleChangeCommand = settings.value("title_change_command").toString();
+    m_appStartupCommand = settings.value("application_startup_command").toString();
+    m_appExitCommand = settings.value("application_exit_command").toString();
+    settings.endGroup();
+
+    connect(qApp, SIGNAL(aboutToQuit()), SLOT(onAppExit()));
+    onAppStartup();
 }
 
 TrackChange::~TrackChange()
@@ -104,6 +104,32 @@ void TrackChange::onFinised()
     }
 }
 
+void TrackChange::onAppStartup()
+{
+    if(QApplication::allWindows().count() == 1 && !m_appStartupCommand.isEmpty()) //detect startup
+    {
+#ifdef Q_OS_WIN
+        QProcess::startDetached(QString("cmd.exe /C %1").arg(m_appStartupCommand));
+#else
+        QStringList args = { "-c", m_appStartupCommand };
+        QProcess::startDetached("sh", args);
+#endif
+    }
+}
+
+void TrackChange::onAppExit()
+{
+    if(!m_appExitCommand.isEmpty())
+    {
+#ifdef Q_OS_WIN
+        QProcess::startDetached(QString("cmd.exe /C %1").arg(m_appExitCommand));
+#else
+        QStringList args = { "-c", m_appExitCommand };
+        QProcess::startDetached("sh", args);
+#endif
+    }
+}
+
 bool TrackChange::executeCommand(const TrackInfo &info, const QString &format)
 {
     TrackInfo tmp = info;
