@@ -9,33 +9,43 @@
         <translation>Definições</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="32"/>
-        <location filename="../settingsdialog.ui" line="42"/>
-        <location filename="../settingsdialog.ui" line="52"/>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../settingsdialog.ui" line="39"/>
+        <location filename="../settingsdialog.ui" line="56"/>
+        <location filename="../settingsdialog.ui" line="73"/>
+        <location filename="../settingsdialog.ui" line="90"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="76"/>
+        <location filename="../settingsdialog.ui" line="29"/>
         <source>Command to run when Qmmp starts new track</source>
         <translation>Comando a executar ao iniciar uma nova faixa</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="83"/>
+        <location filename="../settingsdialog.ui" line="46"/>
         <source>Command to run toward to end of a track</source>
         <translation>Comando a executar ao terminar a faixa</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="90"/>
+        <location filename="../settingsdialog.ui" line="63"/>
         <source>Command to run when Qmmp reaches the end of the playlist</source>
         <translation>Comando a executar ao atingir o fim da lista de reprodução</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="97"/>
+        <location filename="../settingsdialog.ui" line="80"/>
         <source>Command to run when title changes (i.e. network streams title)</source>
         <translation>Comando a executar ao mudar o título (exemplo: emissões web)</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="97"/>
+        <source>Command to run on application startup:</source>
+        <translation>Comando a executar ao iniciar a aplicação:</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="104"/>
+        <source>Command to run on application exit:</source>
+        <translation>Comando a executar ao sair da aplicação:</translation>
+    </message>
 </context>
 <context>
     <name>TrackChangeFactory</name>
