@@ -6,7 +6,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>UDisks Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>UDisks Eklenti Ayarları</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
@@ -44,22 +44,22 @@
     <message>
         <location filename="../udisks2factory.cpp" line="30"/>
         <source>UDisks2 Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>UDisks2 Eklentisi</translation>
     </message>
     <message>
         <location filename="../udisks2factory.cpp" line="50"/>
         <source>About UDisks2 Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>UDisks2 Eklentisi Hakkında</translation>
     </message>
     <message>
         <location filename="../udisks2factory.cpp" line="51"/>
         <source>Qmmp UDisks2 Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Qmmp UDisks2 Eklentisi</translation>
     </message>
     <message>
         <location filename="../udisks2factory.cpp" line="52"/>
         <source>This plugin provides removable devices detection using UDisks2</source>
-        <translation type="unfinished"></translation>
+        <translation>Bu eklenti UDisks2 kullanılarak çıkarılabilir aygıtların algılanmasını sağlar</translation>
     </message>
     <message>
         <location filename="../udisks2factory.cpp" line="53"/>
@@ -70,12 +70,12 @@
 <context>
     <name>UDisks2Plugin</name>
     <message>
-        <location filename="../udisks2plugin.cpp" line="129"/>
+        <location filename="../udisks2plugin.cpp" line="134"/>
         <source>Add CD &quot;%1&quot;</source>
         <translation>CD &quot;%1&quot; Ekle</translation>
     </message>
     <message>
-        <location filename="../udisks2plugin.cpp" line="137"/>
+        <location filename="../udisks2plugin.cpp" line="142"/>
         <source>Add Volume &quot;%1&quot;</source>
         <translation>&quot;%1&quot; Aygıtını Ekle</translation>
     </message>
