@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2013 by Ilya Kotov                                      *
- *   forkotov02@hotmail.ru                                                 *
+ *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,13 +31,13 @@ typedef QMap<QString,QVariantMap> QVariantMapMap;
 Q_DECLARE_METATYPE(QVariantMapMap)
 
 /**
-    @author Ilya Kotov <forkotov02@hotmail.ru>
+    @author Ilya Kotov <forkotov02@ya.ru>
 */
 class UDisks2Manager : public QObject
 {
 Q_OBJECT
 public:
-    UDisks2Manager(QObject *parent = 0);
+    UDisks2Manager(QObject *parent = nullptr);
 
     ~UDisks2Manager();
 
