@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,8 +48,8 @@ UDisks2Plugin::UDisks2Plugin(QObject *parent) : QObject(parent)
     m_addTracks = false; //do not load tracks on startup
     m_addFiles = false;
     //find existing devices
-    QList<QDBusObjectPath> devs = m_manager->findAllDevices();
-    foreach(QDBusObjectPath o, devs)
+    const QList<QDBusObjectPath> devs = m_manager->findAllDevices();
+    for(const QDBusObjectPath &o : qAsConst(devs))
         addDevice(o);
     //load remaining settings
     m_addTracks = settings.value("add_tracks", false).toBool();
@@ -65,22 +65,27 @@ UDisks2Plugin::~UDisks2Plugin()
 
 void UDisks2Plugin::removeDevice(QDBusObjectPath o)
 {
-    foreach(UDisks2Device *device, m_devices)
+    QList<UDisks2Device *>::iterator it = m_devices.begin();
+    while(it != m_devices.end())
     {
-        if (device->objectPath() == o)
+        if((*it)->objectPath() == o)
         {
-            m_devices.removeAll(device);
-            delete device;
+            delete (*it);
+            it = m_devices.erase(it);
             qDebug("UDisks2Plugin: removed device: \"%s\"", qPrintable(o.path()));
             updateActions();
             break;
         }
+        else
+        {
+            ++it;
+        }
     }
 }
 
 void UDisks2Plugin::addDevice(QDBusObjectPath o)
 {
-    foreach(UDisks2Device *device, m_devices) //is it already exists?
+    for(const UDisks2Device *device : qAsConst(m_devices)) //is it already exists?
     {
         if (device->objectPath() == o)
             return;
@@ -101,7 +106,7 @@ void UDisks2Plugin::addDevice(QDBusObjectPath o)
 void UDisks2Plugin::updateActions()
 {
     // add action for cd audio or mounted volume
-    foreach(UDisks2Device *device, m_devices)
+    for(const UDisks2Device *device : qAsConst(m_devices))
     {
         QString dev_path;
         if (m_detectCDA && device->isAudio()) //cd audio
@@ -157,7 +162,7 @@ void UDisks2Plugin::updateActions()
         }
     }
     // remove action if device is unmounted/removed
-    foreach(QAction *action, m_actions->actions ())
+    for(QAction *action : m_actions->actions())
     {
         if (!findDevice(action))
         {
@@ -179,7 +184,7 @@ void UDisks2Plugin::processAction(QAction *action)
 
 QAction *UDisks2Plugin::findAction(const QString &dev_path)
 {
-    foreach(QAction *action, m_actions->actions ())
+    for(QAction *action : m_actions->actions())
     {
         if (action->data().toString() == dev_path)
             return action;
@@ -189,7 +194,7 @@ QAction *UDisks2Plugin::findAction(const QString &dev_path)
 
 UDisks2Device *UDisks2Plugin::findDevice(QAction *action)
 {
-    foreach(UDisks2Device *device, m_devices)
+    for(UDisks2Device *device : qAsConst(m_devices))
     {
         QString dev_path;
         if (device->isAudio())
@@ -212,7 +217,7 @@ void UDisks2Plugin::addPath(const QString &path)
 {
     PlayListModel *model = PlayListManager::instance()->selectedPlayList();
 
-    foreach(PlayListItem *item, model->items()) // Is it already exist?
+    for(PlayListItem *item : model->items()) // Is it already exist?
     {
         if(item->isGroup())
             continue;
