@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -59,11 +59,11 @@ bool DecoderArchive::initialize()
     }
 
     //is this file supported by qmmp?
-    QList<DecoderFactory *> filtered = Decoder::findByFileExtension(filePath);
-    foreach (DecoderFactory *f, filtered)
+    QList<DecoderFactory *> filtered;
+    for(DecoderFactory *f : Decoder::findByFileExtension(filePath))
     {
-        if(f->properties().noInput)
-            filtered.removeAll(f); //remove all factories without streaming input
+        if(!f->properties().noInput)
+            filtered << f; //add all factories with streaming input
     }
 
     if(filtered.isEmpty())
@@ -86,7 +86,7 @@ bool DecoderArchive::initialize()
     else
     {
         //multiple factories, so trying to determine by content
-        foreach (DecoderFactory *fact, filtered)
+        for(DecoderFactory *fact : qAsConst(filtered))
         {
             if(fact->canDecode(m_input))
             {
