@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -104,11 +104,11 @@ QList<TrackInfo *> DecoderArchiveFactory::createPlayList(const QString &path, Tr
             }
 
             //is this file supported by qmmp?
-            QList<DecoderFactory *> filtered = Decoder::findByFileExtension(filePath);
-            foreach (DecoderFactory *f, filtered)
+            QList<DecoderFactory *> filtered;
+            for(DecoderFactory *f : Decoder::findByFileExtension(filePath))
             {
-                if(f->properties().noInput)
-                    filtered.removeAll(f); //remove all factories without streaming input
+                if(!f->properties().noInput)
+                    filtered << f; //add all factories with streaming input
             }
 
             if(!filtered.isEmpty())
