@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -72,7 +72,7 @@ QList<TrackInfo *> DecoderCDAudioFactory::createPlayList(const QString &path, Tr
     QString device_path = path;
     device_path.remove("cdda://");
     QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path, parts);
-    foreach(CDATrack t, tracks)
+    for(const CDATrack &t : qAsConst(tracks))
     {
         list << new TrackInfo(t.info);
     }
