@@ -26,7 +26,7 @@
 
 class Output;
 class QIDevice;
-class CUEParser;
+class CueFile;
 
 class DecoderCUE : public Decoder
 {
@@ -50,7 +50,7 @@ private:
     qint64 length_in_bytes;
     qint64 m_totalBytes;
     QString m_path;
-    CUEParser *m_parser;
+    CueFile *m_cueFile;
     int m_track;
     char *m_buf; //buffer for remainig data
     qint64 m_buf_size;
