@@ -20,6 +20,8 @@
 
 #include <QSettings>
 #include <QMessageBox>
+#include <QFileInfo>
+#include <qmmp/cueparser.h>
 extern "C"{
 #include <libavformat/avformat.h>
 #include <libavcodec/avcodec.h>
@@ -30,6 +32,7 @@ extern "C"{
 #include "ffmpegmetadatamodel.h"
 #include "settingsdialog.h"
 #include "decoder_ffmpeg.h"
+#include "decoder_ffmpegcue.h"
 #include "decoderffmpegfactory.h"
 
 
@@ -71,7 +74,7 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
         return true;
     else if(filters.contains("*.dts") && formats.contains("dts"))
         return true;
-    else if(filters.contains("*.mka") && formats.contains("mka"))
+    else if(filters.contains("*.mka") && (formats.contains("mka") || formats.contains("matroska")))
         return true;
     else if(filters.contains("*.vqf") && formats.contains("vqf"))
         return true;
@@ -81,7 +84,9 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
         return true;
     else if(filters.contains("*.m4a") && (formats.contains("m4a") || formats.contains("mp4")))
         return true;
-    else if(filters.contains("*.tak"))
+    else if(filters.contains("*.tak") && formats.contains("tak"))
+        return true;
+    else if(formats.contains("matroska") && avcodec_find_decoder(AV_CODEC_ID_OPUS) && i->isSequential()) //audio from YouTube
         return true;
     return false;
 }
@@ -89,8 +94,9 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
 DecoderProperties DecoderFFmpegFactory::properties() const
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QStringList filters;
-    filters << "*.wma" << "*.ape" << "*.tta" << "*.m4a" << "*.aac" << "*.ra" << "*.shn" << "*.vqf" << "*.ac3" << "*.tak";
+    QStringList filters = {
+        "*.wma", "*.ape", "*.tta", "*.m4a", "*.aac", "*.ra", "*.shn", "*.vqf", "*.ac3", "*.tak", "*.dsf", "*.dsdiff"
+    };
     filters = settings.value("FFMPEG/filters", filters).toStringList();
 
     if(!avcodec_find_decoder(AV_CODEC_ID_WMAV1))
@@ -119,7 +125,11 @@ DecoderProperties DecoderFFmpegFactory::properties() const
         filters.removeAll("*.vqf");
     if(!avcodec_find_decoder(AV_CODEC_ID_TAK))
         filters.removeAll("*.tak");
-
+    if(!avcodec_find_decoder(AV_CODEC_ID_DSD_LSBF))
+    {
+        filters.removeAll("*.dsf");
+        filters.removeAll("*.dsdiff");
+    }
 
     DecoderProperties properties;
     properties.name = tr("FFmpeg Plugin");
@@ -149,28 +159,43 @@ DecoderProperties DecoderFFmpegFactory::properties() const
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.noInput = false;
+    properties.protocols << "ffmpeg";
     properties.priority = 10;
     return properties;
 }
 
 Decoder *DecoderFFmpegFactory::create(const QString &path, QIODevice *input)
 {
-    return new DecoderFFmpeg(path, input);
+    if(path.startsWith("ffmpeg://"))
+        return new DecoderFFmpegCue(path);
+    else
+        return new DecoderFFmpeg(path, input);
 }
 
 QList<TrackInfo *> DecoderFFmpegFactory::createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *)
 {
-    TrackInfo *info = new TrackInfo(path);
+    int track = -1; //cue track
+    QString filePath = path;
 
-    if(parts == TrackInfo::NoParts)
+    if(path.contains("://")) //is it cue track?
+    {
+        filePath.remove("ffmpeg://");
+        filePath.remove(QRegExp("#\\d+$"));
+        track = path.section("#", -1).toInt();
+        parts = TrackInfo::AllParts; //extract all metadata for single cue track
+    }
+
+     TrackInfo *info = new TrackInfo(filePath);
+
+    if(parts == TrackInfo::Parts())
         return QList<TrackInfo*>() << info;
 
     AVFormatContext *in = nullptr;
 
 #ifdef Q_OS_WIN
-    if(avformat_open_input(&in, path.toUtf8().constData(), nullptr, nullptr) < 0)
+    if(avformat_open_input(&in, filePath.toUtf8().constData(), nullptr, nullptr) < 0)
 #else
-    if(avformat_open_input(&in, path.toLocal8Bit().constData(), nullptr, nullptr) < 0)
+    if(avformat_open_input(&in, filePath.toLocal8Bit().constData(), nullptr, nullptr) < 0)
 #endif
     {
         qDebug("DecoderFFmpegFactory: unable to open file");
@@ -180,8 +205,44 @@ QList<TrackInfo *> DecoderFFmpegFactory::createPlayList(const QString &path, Tra
 
     avformat_find_stream_info(in, nullptr);
 
+    if(parts & TrackInfo::Properties)
+    {
+        int idx = av_find_best_stream(in, AVMEDIA_TYPE_AUDIO, -1, -1, nullptr, 0);
+        if(idx >= 0)
+        {
+    #if (LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(57,48,0)) //ffmpeg-3.1:  57.48.101
+            AVCodecParameters *c = in->streams[idx]->codecpar;
+    #else
+            AVCodecContext *c = in->streams[idx]->codec;
+    #endif
+            info->setValue(Qmmp::BITRATE, int(c->bit_rate) / 1000);
+            info->setValue(Qmmp::SAMPLERATE, c->sample_rate);
+            info->setValue(Qmmp::CHANNELS, c->channels);
+            info->setValue(Qmmp::BITS_PER_SAMPLE, c->bits_per_raw_sample);
+
+            AVCodec *codec = avcodec_find_decoder(c->codec_id);
+            if(codec)
+                info->setValue(Qmmp::FORMAT_NAME, QString::fromLatin1(codec->name));
+            info->setValue(Qmmp::FILE_SIZE, QFileInfo(filePath).size()); //adds file size for cue tracks
+            info->setDuration(in->duration * 1000 / AV_TIME_BASE);
+        }
+    }
+
     if(parts & TrackInfo::MetaData)
     {
+        AVDictionaryEntry *cuesheet = av_dict_get(in->metadata,"cuesheet",nullptr,0);
+        if(cuesheet)
+        {
+            CueParser parser(cuesheet->value);
+            parser.setDuration(info->duration());
+            parser.setProperties(info->properties());
+            parser.setUrl("ffmpeg", filePath);
+
+            avformat_close_input(&in);
+            delete info;
+            return (track > 0) ? parser.createPlayList(track) : parser.createPlayList();
+        }
+
         AVDictionaryEntry *album = av_dict_get(in->metadata,"album",nullptr,0);
         AVDictionaryEntry *album_artist = av_dict_get(in->metadata,"album_artist",nullptr,0);
         AVDictionaryEntry *artist = av_dict_get(in->metadata,"artist",nullptr,0);
@@ -228,28 +289,6 @@ QList<TrackInfo *> DecoderFFmpegFactory::createPlayList(const QString &path, Tra
             info->setValue(Qmmp::TRACK, track->value);
     }
 
-    if(parts & TrackInfo::Properties)
-    {
-        int idx = av_find_best_stream(in, AVMEDIA_TYPE_AUDIO, -1, -1, nullptr, 0);
-        if(idx >= 0)
-        {
-    #if (LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(57,48,0)) //ffmpeg-3.1:  57.48.101
-            AVCodecParameters *c = in->streams[idx]->codecpar;
-    #else
-            AVCodecContext *c = in->streams[idx]->codec;
-    #endif
-            info->setValue(Qmmp::BITRATE, int(c->bit_rate) / 1000);
-            info->setValue(Qmmp::SAMPLERATE, c->sample_rate);
-            info->setValue(Qmmp::CHANNELS, c->channels);
-            info->setValue(Qmmp::BITS_PER_SAMPLE, c->bits_per_raw_sample);
-
-            AVCodec *codec = avcodec_find_decoder(c->codec_id);
-            if(codec)
-                info->setValue(Qmmp::FORMAT_NAME, QString::fromLatin1(codec->name));
-            info->setDuration(in->duration * 1000 / AV_TIME_BASE);
-        }
-    }
-
     avformat_close_input(&in);
     return QList<TrackInfo*>() << info;
 }
