@@ -1,55 +1,55 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pt">
+<TS version="2.1" language="pt">
 <context>
     <name>DecoderModPlugFactory</name>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="47"/>
+        <location filename="../decodermodplugfactory.cpp" line="46"/>
         <source>ModPlug Plugin</source>
         <translation>Suplemento ModPlug</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="53"/>
+        <location filename="../decodermodplugfactory.cpp" line="52"/>
         <source>ModPlug Files</source>
         <translation>Ficheiros ModPlug</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="119"/>
+        <location filename="../decodermodplugfactory.cpp" line="136"/>
         <source>About ModPlug Audio Plugin</source>
         <translation>Sobre o suplemento ModPlug Audio</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="120"/>
+        <location filename="../decodermodplugfactory.cpp" line="137"/>
         <source>Qmmp ModPlug Audio Plugin</source>
         <translation>Suplemento Qmmp ModPlug Audio</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="121"/>
+        <location filename="../decodermodplugfactory.cpp" line="138"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="122"/>
+        <location filename="../decodermodplugfactory.cpp" line="139"/>
         <source>Based on the Modplug Plugin for Xmms</source>
         <translation>Baseado no Modplug Plugin for Xmms</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="123"/>
+        <location filename="../decodermodplugfactory.cpp" line="140"/>
         <source>Modplug Plugin developers:</source>
         <translation>Programadores ModPlug:</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="124"/>
+        <location filename="../decodermodplugfactory.cpp" line="141"/>
         <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
         <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="125"/>
+        <location filename="../decodermodplugfactory.cpp" line="142"/>
         <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
         <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="126"/>
+        <location filename="../decodermodplugfactory.cpp" line="143"/>
         <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
         <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
     </message>
@@ -58,53 +58,38 @@
     <name>ModPlugMetaDataModel</name>
     <message>
         <location filename="../modplugmetadatamodel.cpp" line="71"/>
-        <source>File name</source>
-        <translation>Nome do ficheiro</translation>
-    </message>
-    <message>
-        <location filename="../modplugmetadatamodel.cpp" line="142"/>
-        <source>Type</source>
-        <translation>Tipo</translation>
-    </message>
-    <message>
-        <location filename="../modplugmetadatamodel.cpp" line="147"/>
-        <source>Length</source>
-        <translation>Duração</translation>
-    </message>
-    <message>
-        <location filename="../modplugmetadatamodel.cpp" line="148"/>
         <source>Speed</source>
         <translation>Velocidade</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="149"/>
+        <location filename="../modplugmetadatamodel.cpp" line="72"/>
         <source>Tempo</source>
         <translation>Tempo</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="150"/>
-        <location filename="../modplugmetadatamodel.cpp" line="171"/>
+        <location filename="../modplugmetadatamodel.cpp" line="73"/>
+        <location filename="../modplugmetadatamodel.cpp" line="94"/>
         <source>Samples</source>
         <translation>Amostras</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="151"/>
-        <location filename="../modplugmetadatamodel.cpp" line="180"/>
+        <location filename="../modplugmetadatamodel.cpp" line="74"/>
+        <location filename="../modplugmetadatamodel.cpp" line="103"/>
         <source>Instruments</source>
         <translation>Instrumentos</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="152"/>
+        <location filename="../modplugmetadatamodel.cpp" line="75"/>
         <source>Patterns</source>
         <translation>Padrões</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="153"/>
+        <location filename="../modplugmetadatamodel.cpp" line="76"/>
         <source>Channels</source>
         <translation>Canais</translation>
     </message>
     <message>
-        <location filename="../modplugmetadatamodel.cpp" line="185"/>
+        <location filename="../modplugmetadatamodel.cpp" line="108"/>
         <source>Comment</source>
         <translation>Comentário</translation>
     </message>
