@@ -140,12 +140,29 @@ bool DecoderMAD::findXingHeader(struct mad_bitptr ptr, unsigned int bitlen)
     if (bitlen < 64)
         return false;
 
+    struct mad_bitptr start = ptr;
     quint32 xing_magic = mad_bit_read(&ptr, 32);
+    bitlen -= 32;
+
     if(xing_magic != XING_MAGIC && xing_magic != XING_MAGIC2)
-        return false;
+    {
+        /*
+         * Due to an unfortunate historical accident, a Xing VBR tag may be
+         * misplaced in a stream with CRC protection. We check for this by
+         * assuming the tag began two octets prior and the high bits of the
+         * following flags field are always zero.
+         */
+
+        if(xing_magic != ((quint64(XING_MAGIC) << 16) & 0xffffffffL) && xing_magic != ((quint64(XING_MAGIC2) << 16) & 0xffffffffL))
+            return false;
+
+        ptr = start;
+        mad_bit_skip(&ptr, 16);
+        bitlen += 16;
+    }
 
     m_xing.flags = mad_bit_read(&ptr, 32);
-    bitlen -= 64;
+    bitlen -= 32;
 
     if (m_xing.flags & XING_FRAMES)
     {
@@ -356,6 +373,14 @@ bool DecoderMAD::findHeader()
     m_freq = header.samplerate;
     m_channels = MAD_NCHANNELS(&header);
     m_bitrate = header.bitrate / 1000;
+
+    if((header.flags & MAD_FLAG_LSF_EXT) && (header.flags & MAD_FLAG_MPEG_2_5_EXT))
+        setProperty(Qmmp::FORMAT_NAME, QString("MPEG-2.5 layer %1").arg(header.layer));
+    else if(header.flags & MAD_FLAG_LSF_EXT)
+        setProperty(Qmmp::FORMAT_NAME, QString("MPEG-2 layer %1").arg(header.layer));
+    else
+        setProperty(Qmmp::FORMAT_NAME, QString("MPEG-1 layer %1").arg(header.layer));
+
     mad_header_finish(&header);
     input()->seek(0);
     m_input_bytes = 0;
@@ -396,6 +421,11 @@ qint64 DecoderMAD::read(unsigned char *data, qint64 size)
             m_play_bytes -= l;
             return l;
         }
+        else
+        {
+            m_skip_bytes = 0;
+            break;
+        }
     }
 
     if(!decodeFrame())
