@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -133,7 +133,11 @@ bool DecoderMPEGFactory::canDecode(QIODevice *input) const
             ;
 
         if(dec_res == 0)
-            dec_res = mad_frame_decode(&frame, &stream);
+        {
+            while ((dec_res = mad_frame_decode(&frame, &stream)) == -1
+                   && MAD_RECOVERABLE(stream.error))
+                ;
+        }
 
         mad_stream_finish(&stream);
         mad_frame_finish(&frame);
@@ -209,10 +213,9 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
 {
     TrackInfo *info = new TrackInfo(path);
 
-    if(parts == TrackInfo::NoParts)
+    if(parts == TrackInfo::Parts())
         return QList<TrackInfo*>() << info;
 
-    TagLib::Tag *tag = nullptr;
     TagLib::FileStream stream(QStringToFileName(path), true);
     TagLib::MPEG::File fileRef(&stream, TagLib::ID3v2::FrameFactory::instance());
 
@@ -221,17 +224,19 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
         settings.beginGroup("MPEG");
 
-        QTextCodec *codec = nullptr;
-
+        QList< QMap<Qmmp::MetaData, QString> > metaData;
         uint tag_array[3];
         tag_array[0] = settings.value("tag_1", SettingsDialog::ID3v2).toInt();
         tag_array[1] = settings.value("tag_2", SettingsDialog::APE).toInt();
         tag_array[2] = settings.value("tag_3", SettingsDialog::ID3v1).toInt();
+        bool merge = settings.value("merge_tags", false).toBool();
 
-        QByteArray codecName;
         for (int i = 0; i < 3; ++i)
         {
-            codecName.clear();
+            QTextCodec *codec = nullptr;
+            TagLib::Tag *tag = nullptr;
+            QByteArray codecName;
+
             switch ((uint) tag_array[i])
             {
             case SettingsDialog::ID3v1:
@@ -249,61 +254,70 @@ QList<TrackInfo *> DecoderMPEGFactory::createPlayList(const QString &path, Track
             case SettingsDialog::Disabled:
                 break;
             }
-            if (tag && !tag->isEmpty())
+
+            if(m_using_rusxmms || codecName.contains("UTF"))
+                codec = QTextCodec::codecForName("UTF-8");
+            else if(!codecName.isEmpty())
+                codec = QTextCodec::codecForName(codecName);
+
+            if (!codec)
+                codec = QTextCodec::codecForName("UTF-8");
+
+            if (tag && codec && !tag->isEmpty())
             {
-                if(codecName.contains("UTF"))
-                    codecName = "UTF-8";
-                if(!codecName.isEmpty())
-                    codec = QTextCodec::codecForName(codecName);
-                break;
+                bool utf = codec->name().contains("UTF");
+                QMap<Qmmp::MetaData, QString> tags = {
+                    { Qmmp::ARTIST, CSTR_TO_QSTR(tag->artist(), utf) },
+                    { Qmmp::ALBUM, CSTR_TO_QSTR(tag->album(), utf) },
+                    { Qmmp::COMMENT, CSTR_TO_QSTR(tag->comment(), utf) },
+                    { Qmmp::GENRE, CSTR_TO_QSTR(tag->genre(), utf) },
+                    { Qmmp::TITLE, CSTR_TO_QSTR(tag->title(), utf) },
+                    { Qmmp::YEAR, QString::number(tag->year()) },
+                    { Qmmp::TRACK, QString::number(tag->track()) },
+                };
+
+                if(tag == fileRef.ID3v2Tag())
+                {
+                    if(!fileRef.ID3v2Tag()->frameListMap()["TPE2"].isEmpty())
+                    {
+                        TagLib::String albumArtist = fileRef.ID3v2Tag()->frameListMap()["TPE2"].front()->toString();
+                        tags.insert(Qmmp::ALBUMARTIST, CSTR_TO_QSTR(albumArtist, utf));
+                    }
+                    if(!fileRef.ID3v2Tag()->frameListMap()["TCOM"].isEmpty())
+                    {
+                        TagLib::String composer = fileRef.ID3v2Tag()->frameListMap()["TCOM"].front()->toString();
+                        tags.insert(Qmmp::COMPOSER, CSTR_TO_QSTR(composer, utf));
+                    }
+                    if(!fileRef.ID3v2Tag()->frameListMap()["TPOS"].isEmpty())
+                    {
+                        TagLib::String disc = fileRef.ID3v2Tag()->frameListMap()["TPOS"].front()->toString();
+                        tags.insert(Qmmp::DISCNUMBER, CSTR_TO_QSTR(disc, utf));
+                    }
+                }
+                else if(tag == fileRef.APETag())
+                {
+                    TagLib::APE::Item fld;
+                    if(!(fld = fileRef.APETag()->itemListMap()["ALBUM ARTIST"]).isEmpty())
+                        tags.insert(Qmmp::ALBUMARTIST, CSTR_TO_QSTR(fld.toString(), true));
+                    if(!(fld = fileRef.APETag()->itemListMap()["COMPOSER"]).isEmpty())
+                        tags.insert(Qmmp::COMPOSER, CSTR_TO_QSTR(fld.toString(), true));
+                }
+
+                metaData << tags;
+
+                if(!merge)
+                    break;
             }
         }
         settings.endGroup();
 
-        if(m_using_rusxmms)
-            codec = QTextCodec::codecForName("UTF-8");
-
-        if (!codec)
-            codec = QTextCodec::codecForName("UTF-8");
-
-        if (tag && codec)
+        for(const QMap<Qmmp::MetaData, QString> &tags : qAsConst(metaData))
         {
-            bool utf = codec->name().contains("UTF");
-            info->setValue(Qmmp::ALBUM, CSTR_TO_QSTR(tag->album(), utf));
-            info->setValue(Qmmp::ARTIST, CSTR_TO_QSTR(tag->artist(), utf));
-            info->setValue(Qmmp::COMMENT, CSTR_TO_QSTR(tag->comment(), utf));
-            info->setValue(Qmmp::GENRE, CSTR_TO_QSTR(tag->genre(), utf));
-            info->setValue(Qmmp::TITLE, CSTR_TO_QSTR(tag->title(), utf));
-            info->setValue(Qmmp::YEAR, tag->year());
-            info->setValue(Qmmp::TRACK, tag->track());
-
-            if(tag == fileRef.ID3v2Tag())
+            for(int i = Qmmp::TITLE; i <= Qmmp::DISCNUMBER; ++i)
             {
-                if(!fileRef.ID3v2Tag()->frameListMap()["TPE2"].isEmpty())
-                {
-                    TagLib::String albumArtist;
-                    albumArtist = fileRef.ID3v2Tag()->frameListMap()["TPE2"].front()->toString();
-                    info->setValue(Qmmp::ALBUMARTIST, CSTR_TO_QSTR(albumArtist, utf));
-                }
-                if(!fileRef.ID3v2Tag()->frameListMap()["TCOM"].isEmpty())
-                {
-                    TagLib::String composer;
-                    composer = fileRef.ID3v2Tag()->frameListMap()["TCOM"].front()->toString();
-                    info->setValue(Qmmp::COMPOSER, CSTR_TO_QSTR(composer, utf));
-                }
-                if(!fileRef.ID3v2Tag()->frameListMap()["TPOS"].isEmpty())
-                {
-                    TagLib::String disc = fileRef.ID3v2Tag()->frameListMap()["TPOS"].front()->toString();
-                    info->setValue(Qmmp::DISCNUMBER, CSTR_TO_QSTR(disc, utf));
-                }
-            }
-            else if(tag == fileRef.APETag())
-            {
-                TagLib::APE::Item fld;
-                if(!(fld = fileRef.APETag()->itemListMap()["ALBUM ARTIST"]).isEmpty())
-                    info->setValue(Qmmp::ALBUMARTIST, CSTR_TO_QSTR(fld.toString(), true));
-                if(!(fld = fileRef.APETag()->itemListMap()["COMPOSER"]).isEmpty())
-                    info->setValue(Qmmp::COMPOSER, CSTR_TO_QSTR(fld.toString(), true));
+                Qmmp::MetaData key = static_cast<Qmmp::MetaData>(i);
+                if(info->value(key).length() < tags.value(key).length())
+                    info->setValue(key, tags.value(key));
             }
         }
     }
