@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,7 @@ SettingsDialog::SettingsDialog(bool using_rusxmms, QWidget *parent)
     m_ui.setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
     findCodecs();
-    foreach (QTextCodec *codec, codecs)
+    for(const QTextCodec *codec : qAsConst(codecs))
     {
         m_ui.id3v1EncComboBox->addItem(codec->name());
         m_ui.id3v2EncComboBox->addItem(codec->name());
@@ -59,6 +59,7 @@ SettingsDialog::SettingsDialog(bool using_rusxmms, QWidget *parent)
     m_ui.firstTagComboBox->setCurrentIndex(settings.value("tag_1", ID3v2).toInt());
     m_ui.secondTagComboBox->setCurrentIndex(settings.value("tag_2", APE).toInt());
     m_ui.thirdTagComboBox->setCurrentIndex(settings.value("tag_3", ID3v1).toInt());
+    m_ui.mergeTagsCheckBox->setChecked(settings.value("merge_tags", false).toBool());
 
     settings.endGroup();
 
@@ -83,6 +84,7 @@ void SettingsDialog::accept()
     settings.setValue("tag_1", m_ui.firstTagComboBox->currentIndex());
     settings.setValue("tag_2", m_ui.secondTagComboBox->currentIndex());
     settings.setValue("tag_3", m_ui.thirdTagComboBox->currentIndex());
+    settings.setValue("merge_tags", m_ui.mergeTagsCheckBox->isChecked());
     settings.endGroup();
     QDialog::accept();
 }
@@ -92,7 +94,7 @@ void SettingsDialog::findCodecs()
     QMap<QString, QTextCodec *> codecMap;
     QRegExp iso8859RegExp("ISO[- ]8859-([0-9]+).*");
 
-    foreach (int mib, QTextCodec::availableMibs())
+    for(int mib : QTextCodec::availableMibs())
     {
         QTextCodec *codec = QTextCodec::codecForMib(mib);
 
