@@ -4,42 +4,42 @@
 <context>
     <name>DecoderMPEGFactory</name>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="175"/>
+        <location filename="../decodermpegfactory.cpp" line="179"/>
         <source>MPEG Plugin</source>
         <translation>Módulo MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="178"/>
+        <location filename="../decodermpegfactory.cpp" line="182"/>
         <source>MPEG Files</source>
         <translation>Archivos MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="386"/>
+        <location filename="../decodermpegfactory.cpp" line="400"/>
         <source>About MPEG Audio Plugin</source>
         <translation>Acerca del módulo de audio MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="387"/>
+        <location filename="../decodermpegfactory.cpp" line="401"/>
         <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
         <translation>Decodificador de audio MPEG 1.0/2.0/2.5 capas 1/2/3</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="388"/>
+        <location filename="../decodermpegfactory.cpp" line="402"/>
         <source>Compiled against:</source>
         <translation>Compilado contra:</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="397"/>
+        <location filename="../decodermpegfactory.cpp" line="411"/>
         <source>mpg123, API version: %1</source>
         <translation>mpg123, versión de API: %1</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="401"/>
+        <location filename="../decodermpegfactory.cpp" line="415"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="402"/>
+        <location filename="../decodermpegfactory.cpp" line="416"/>
         <source>Source code based on mq3 and madplay projects</source>
         <translation>Código fuente basado sobre proyectos mq3 y madplay</translation>
     </message>
@@ -141,17 +141,22 @@
         <translation>Tercera:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="252"/>
+        <location filename="../settingsdialog.ui" line="243"/>
+        <source>Merge selected tag types</source>
+        <translation>Combinar tipos de etiquetas seleccionados</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="262"/>
         <source>Encodings</source>
         <translation>Codificaciones</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="264"/>
+        <location filename="../settingsdialog.ui" line="274"/>
         <source>ID3v1 encoding:</source>
         <translation>Codificación ID3v1:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="290"/>
+        <location filename="../settingsdialog.ui" line="300"/>
         <source>ID3v2 encoding:</source>
         <translation>Codificación ID3v2:</translation>
     </message>
