@@ -4,44 +4,44 @@
 <context>
     <name>DecoderMPEGFactory</name>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="175"/>
+        <location filename="../decodermpegfactory.cpp" line="179"/>
         <source>MPEG Plugin</source>
         <translation>MPEG Eklentisi</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="178"/>
+        <location filename="../decodermpegfactory.cpp" line="182"/>
         <source>MPEG Files</source>
         <translation>MPEG Dosyaları</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="386"/>
+        <location filename="../decodermpegfactory.cpp" line="400"/>
         <source>About MPEG Audio Plugin</source>
         <translation>MPEG Ses Eklentisi Hakkında</translation>
     </message>
-    <message>
-        <location filename="../decodermpegfactory.cpp" line="387"/>
-        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpegfactory.cpp" line="388"/>
-        <source>Compiled against:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpegfactory.cpp" line="397"/>
-        <source>mpg123, API version: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../decodermpegfactory.cpp" line="401"/>
+        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
+        <translation>MPEG 1.0 / 2.0 / 2.5 katman 1/2/3 ses kod çözücü</translation>
+    </message>
+    <message>
+        <location filename="../decodermpegfactory.cpp" line="402"/>
+        <source>Compiled against:</source>
+        <translation>Dayanarak derlendi</translation>
+    </message>
+    <message>
+        <location filename="../decodermpegfactory.cpp" line="411"/>
+        <source>mpg123, API version: %1</source>
+        <translation>mpg123, API uyarlaması:% 1</translation>
+    </message>
+    <message>
+        <location filename="../decodermpegfactory.cpp" line="415"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="402"/>
+        <location filename="../decodermpegfactory.cpp" line="416"/>
         <source>Source code based on mq3 and madplay projects</source>
-        <translation type="unfinished"></translation>
+        <translation>Kaynak kodu Mq3 ve madplay projeleri temellidir.</translation>
     </message>
 </context>
 <context>
@@ -52,22 +52,22 @@
         <location filename="../mpegmetadatamodel.cpp" line="71"/>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Kip</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="77"/>
         <source>Protection</source>
-        <translation type="unfinished"></translation>
+        <translation>Korunum</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="78"/>
         <source>Copyright</source>
-        <translation type="unfinished"></translation>
+        <translation>Telif hakkı</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="79"/>
         <source>Original</source>
-        <translation type="unfinished"></translation>
+        <translation>Menşe</translation>
     </message>
 </context>
 <context>
@@ -80,17 +80,17 @@
     <message>
         <location filename="../settingsdialog.ui" line="35"/>
         <source>Decoder</source>
-        <translation type="unfinished"></translation>
+        <translation>Kodlayıcı</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
         <source>MAD</source>
-        <translation type="unfinished"></translation>
+        <translation>MAD</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="48"/>
         <source>MPG123</source>
-        <translation type="unfinished"></translation>
+        <translation>MPG123</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="77"/>
@@ -141,17 +141,22 @@
         <translation>Üçüncü:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="252"/>
+        <location filename="../settingsdialog.ui" line="243"/>
+        <source>Merge selected tag types</source>
+        <translation>Seçili etiket türlerini birleştir</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="262"/>
         <source>Encodings</source>
         <translation>Kodlamalar</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="264"/>
+        <location filename="../settingsdialog.ui" line="274"/>
         <source>ID3v1 encoding:</source>
         <translation>ID3v1 kodlaması:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="290"/>
+        <location filename="../settingsdialog.ui" line="300"/>
         <source>ID3v2 encoding:</source>
         <translation>ID3v2 kodlaması:</translation>
     </message>
