@@ -31,12 +31,12 @@ class SettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    SettingsDialog(SidDatabase *db, QWidget *parent = 0);
+    SettingsDialog(SidDatabase *db, QWidget *parent = nullptr);
 
     virtual ~SettingsDialog();
 
 public slots:
-    virtual void accept();
+    virtual void accept() override;
 
 private:
     Ui::SettingsDialog m_ui;
