@@ -1,37 +1,37 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_CN">
+<TS version="2.1" language="zh_CN">
 <context>
     <name>DecoderSIDFactory</name>
     <message>
-        <location filename="../decodersidfactory.cpp" line="77"/>
+        <location filename="../decodersidfactory.cpp" line="58"/>
         <source>SID Plugin</source>
         <translation>SID插件</translation>
     </message>
     <message>
-        <location filename="../decodersidfactory.cpp" line="79"/>
+        <location filename="../decodersidfactory.cpp" line="60"/>
         <source>SID Files</source>
         <translation>SID文件</translation>
     </message>
     <message>
-        <location filename="../decodersidfactory.cpp" line="133"/>
+        <location filename="../decodersidfactory.cpp" line="114"/>
         <source>About SID Audio Plugin</source>
         <translation>关于SID音频插件</translation>
     </message>
     <message>
-        <location filename="../decodersidfactory.cpp" line="134"/>
+        <location filename="../decodersidfactory.cpp" line="115"/>
         <source>Qmmp SID Audio Plugin</source>
         <translation>Qmmp播放器SID音频插件</translation>
     </message>
     <message>
-        <location filename="../decodersidfactory.cpp" line="135"/>
+        <location filename="../decodersidfactory.cpp" line="116"/>
         <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
         <translation>本插件使用libsidplayfp文件库播放科莫多64音乐文件</translation>
     </message>
     <message>
-        <location filename="../decodersidfactory.cpp" line="136"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <location filename="../decodersidfactory.cpp" line="117"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
