@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,11 +24,10 @@
 #include <QRegExp>
 #include <math.h>
 #include <stdint.h>
+#include <qmmp/cueparser.h>
 #include <qmmp/buffer.h>
-#include <qmmp/output.h>
 #include <stdlib.h>
 #include "decoder_wavpack.h"
-#include "cueparser.h"
 
 // Decoder class
 
@@ -36,17 +35,6 @@ DecoderWavPack::DecoderWavPack(const QString &path)
         : Decoder()
 {
     m_path = path;
-    m_totalTime = 0.0;
-    m_chan = 0;
-    m_context = nullptr;
-    m_parser = nullptr;
-    m_output_buf = nullptr;
-    m_length_in_bytes = 0;
-    m_totalBytes = 0;
-    m_frame_size = 0;
-    m_offset = 0;
-    m_bps = 0;
-    m_track = 0;
 }
 
 DecoderWavPack::~DecoderWavPack()
@@ -62,7 +50,7 @@ bool DecoderWavPack::initialize()
     m_chan = 0;
     m_totalTime = 0;
 
-    char err [80];
+    char err[80] = { 0 };
     if (m_path.startsWith("wvpack://")) //embeded cue track
     {
         QString p = m_path;
@@ -80,14 +68,15 @@ bool DecoderWavPack::initialize()
             return false;
         }
         int cue_len = WavpackGetTagItem (m_context, "cuesheet", nullptr, 0);
-        char *value;
-        if (cue_len)
+        if (cue_len > 0)
         {
-            value = (char*)malloc (cue_len * 2 + 1);
-            WavpackGetTagItem (m_context, "cuesheet", value, cue_len + 1);
-            m_parser = new CUEParser(value, p);
+            char *value = (char*)malloc (cue_len * 2 + 1);
+            WavpackGetTagItem(m_context, "cuesheet", value, cue_len + 1);
+            m_parser = new CueParser(value);
+            m_parser->setDuration((qint64)WavpackGetNumSamples(m_context) * 1000 / WavpackGetSampleRate(m_context));
+            m_parser->setUrl("wvpack", p);
             m_track = m_path.section("#", -1).toInt();
-            if(m_track > m_parser->count())
+            if(m_track < 1 || m_track > m_parser->count())
             {
                 qWarning("DecoderWavPack: invalid cuesheet comment");
                 return false;
@@ -155,7 +144,7 @@ bool DecoderWavPack::initialize()
         m_offset = m_parser->offset(m_track);
         m_length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().frameSize() * m_length/1000;
-        setReplayGainInfo(m_parser->replayGain(m_track));
+        setReplayGainInfo(m_parser->info(m_track)->replayGainInfo());
         seek(0);
     }
     m_totalBytes = 0;
@@ -218,7 +207,7 @@ qint64 DecoderWavPack::read(unsigned char *data, qint64 size)
 const QString DecoderWavPack::nextURL() const
 {
     if(m_parser && m_track +1 <= m_parser->count())
-        return m_parser->trackURL(m_track + 1);
+        return m_parser->url(m_track + 1);
     else
         return QString();
 }
@@ -234,7 +223,7 @@ void DecoderWavPack::next()
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
         addMetaData(m_parser->info(m_track)->metaData());
-        setReplayGainInfo(m_parser->replayGain(m_track));
+        setReplayGainInfo(m_parser->info(m_track)->replayGainInfo());
         m_totalBytes = 0;
     }
 }
