@@ -24,7 +24,6 @@
 #include <QString>
 #include <QIODevice>
 #include <QWidget>
-
 #include <qmmp/output.h>
 #include <qmmp/outputfactory.h>
 
@@ -37,13 +36,12 @@ Q_PLUGIN_METADATA(IID "org.qmmp.qmmp.OutputFactoryInterface.1.0")
 Q_INTERFACES(OutputFactory)
 
 public:
-    const OutputProperties properties() const;
-    Output* create();
-    Volume *createVolume();
-    void showSettings(QWidget* parent);
-    void showAbout(QWidget *parent);
-    QTranslator *createTranslator(QObject *parent);
-
+    OutputProperties properties() const override;
+    Output* create() override;
+    Volume *createVolume() override;
+    void showSettings(QWidget* parent) override;
+    void showAbout(QWidget *parent) override;
+    QString translation() const override;
 };
 
 #endif
