@@ -1,27 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<TS version="2.1" language="pl_PL">
 <context>
     <name>OutputJACKFactory</name>
     <message>
-        <location filename="../outputjackfactory.cpp" line="31"/>
+        <location filename="../outputjackfactory.cpp" line="30"/>
         <source>JACK Plugin</source>
         <translation>Wtyczka JACK</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="54"/>
+        <location filename="../outputjackfactory.cpp" line="53"/>
         <source>About Jack Output Plugin</source>
-        <translation>O wtyczce dźwiękowej Jack</translation>
+        <translation>O wtyczce wyjściowej Jack</translation>
+    </message>
+    <message>
+        <location filename="../outputjackfactory.cpp" line="54"/>
+        <source>Qmmp Jack Output Plugin</source>
+        <translation>Wtyczka wyjściowa Jack dla Qmmp</translation>
     </message>
     <message>
         <location filename="../outputjackfactory.cpp" line="55"/>
-        <source>Qmmp Jack Output Plugin</source>
-        <translation>Wtyczka Jack dla Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../outputjackfactory.cpp" line="56"/>
         <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
-        <translation>Autor: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
+        <translation>Napisana przez: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
     </message>
 </context>
 </TS>
