@@ -32,12 +32,12 @@ public:
     OutputNull();
     ~OutputNull();
 
-    bool initialize(quint32, ChannelMap map, Qmmp::AudioFormat format);
+    bool initialize(quint32, ChannelMap map, Qmmp::AudioFormat format) override;
     //output api
-    qint64 latency();
-    qint64 writeAudio(unsigned char *data, qint64 maxSize);
-    void drain();
-    void reset();
+    qint64 latency() override;
+    qint64 writeAudio(unsigned char *data, qint64 maxSize) override;
+    void drain() override;
+    void reset() override;
 
 private:
     qint64 m_bytes_per_second;
