@@ -1,26 +1,26 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="kk_KZ">
+<TS version="2.1" language="kk_KZ">
 <context>
     <name>OutputNullFactory</name>
     <message>
-        <location filename="../outputnullfactory.cpp" line="31"/>
+        <location filename="../outputnullfactory.cpp" line="30"/>
         <source>Null Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="55"/>
+        <location filename="../outputnullfactory.cpp" line="54"/>
         <source>About Null Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="56"/>
+        <location filename="../outputnullfactory.cpp" line="55"/>
         <source>Qmmp Null Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="57"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../outputnullfactory.cpp" line="56"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
