@@ -1,27 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pl_PL">
+<TS version="2.1" language="pl_PL">
 <context>
     <name>OutputNullFactory</name>
     <message>
-        <location filename="../outputnullfactory.cpp" line="31"/>
+        <location filename="../outputnullfactory.cpp" line="30"/>
         <source>Null Plugin</source>
         <translation>Wtyczka Null</translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="55"/>
+        <location filename="../outputnullfactory.cpp" line="54"/>
         <source>About Null Output Plugin</source>
         <translation>O wtyczce wyjściowej Null</translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="56"/>
+        <location filename="../outputnullfactory.cpp" line="55"/>
         <source>Qmmp Null Output Plugin</source>
         <translation>Wtyczka wyjściowa Null dla Qmmp</translation>
     </message>
     <message>
-        <location filename="../outputnullfactory.cpp" line="57"/>
+        <location filename="../outputnullfactory.cpp" line="56"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 </TS>
