@@ -1,25 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sk_SK">
+<TS version="2.1" language="sk">
 <context>
     <name>OutputNullFactory</name>
     <message>
-        <location filename="../outputnullfactory.cpp" line="31"/>
+        <location filename="../outputnullfactory.cpp" line="30"/>
         <source>Null Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Plugin Null</translation>
+    </message>
+    <message>
+        <location filename="../outputnullfactory.cpp" line="54"/>
+        <source>About Null Output Plugin</source>
+        <translation>O plugine Null výstup</translation>
     </message>
     <message>
         <location filename="../outputnullfactory.cpp" line="55"/>
-        <source>About Null Output Plugin</source>
-        <translation type="unfinished"></translation>
+        <source>Qmmp Null Output Plugin</source>
+        <translation>Qmmp plugin Null výstup</translation>
     </message>
     <message>
         <location filename="../outputnullfactory.cpp" line="56"/>
-        <source>Qmmp Null Output Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../outputnullfactory.cpp" line="57"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation type="unfinished"></translation>
     </message>
